@@ -557,6 +557,7 @@ OC.L10N.register(
     "Blocked" : "Estetty",
     "Active" : "Aktiivinen",
     "Expired" : "Vanhentunut",
+    "Never" : "Ei koskaan",
     "The account could not be deleted. Please try again later." : "Tätä tiliä ei voitu poistaa. Yritä myöhemmin uudelleen.",
     "URL of this Nextcloud instance" : "Tämän Nextcloud-instanssin URL-osoite",
     "Email of the user" : "Käyttäjän sähköpostiosoite",
@@ -565,6 +566,8 @@ OC.L10N.register(
     "Status" : "Tila",
     "Created at" : "Luotu",
     "Expires at" : "Vanhenee",
+    "Yes" : "Kyllä",
+    "No" : "Ei",
     "_%n user_::_%n users_" : ["%n käyttäjä","%n käyttäjää"],
     "Installed version: {version}" : "Asennettu versio: {version}",
     "Matterbridge binary was not found or couldn't be executed." : "Matterbridge-binääriä ei löytynyt tai sitä ei voitu suorittaa.",
@@ -626,6 +629,14 @@ OC.L10N.register(
     "Search participants" : "Etsi osallistujia",
     "No results" : "Ei tuloksia",
     "Done" : "Valmis",
+    "Raise hand" : "Nosta käsi",
+    "Raise hand (R)" : "Nosta käsi (R)",
+    "Lower hand" : "Laske käsi",
+    "Lower hand (R)" : "Laske käsi (R)",
+    "Exit full screen (F)" : "Poistu koko näytön tilasta (F)",
+    "Full screen (F)" : "Koko näyttö (F)",
+    "Speaker view" : "Puhujan näkymä",
+    "Grid view" : "Ruudukkonäkymä",
     "This conversation is read-only" : "Keskustelu on \"vain luku\"-tilassa",
     "{nickName} raised their hand." : "{nickName} nosti kätensä.",
     "A participant raised their hand." : "Osallistuja nosti kätensä.",
@@ -645,6 +656,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Mykistä äänet (M)",
     "Unmute audio" : "Palauta äänet",
     "Unmute audio (M)" : "Palauta äänet (M)",
+    "None" : "Ei mitään",
     "Access to camera was denied" : "Pääsy kameraan estettiin",
     "Error while accessing camera: It is likely in use by another program" : "Virhe yrittäessä käyttää kameraa: se on luultavasti toisen ohjelman käytössä",
     "Error while accessing camera" : "Virhe käyttäessä kameraa",
@@ -731,8 +743,6 @@ OC.L10N.register(
     "Be careful, these actions cannot be undone." : "Ole varovainen, näitä toimintoja ei voi perua.",
     "Leave conversation" : "Poistu keskustelusta",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Kun olet kerran poistunut suljetusta keskustelusta, tarvitset kutsun liittyäksesi uudelleen siihen. Avoimeen keskusteluun on mahdollista liittyä milloin hyvänsä.",
-    "No" : "Ei",
-    "Yes" : "Kyllä",
     "Delete conversation" : "Poista keskustelu",
     "Permanently delete this conversation." : "Poista tämä keskustelu pysyvästi.",
     "Delete chat messages" : "Poista keskustelun viestit",
@@ -811,6 +821,7 @@ OC.L10N.register(
     "Decline invitation" : "Kieltäydy kutsusta",
     "Accept invitation" : "Hyväksy kutsu",
     "No pending invitations" : "Ei odottavia kutsuja",
+    "Home" : "Koti",
     "Unread" : "Lukematon",
     "No matches found" : "Ei tuloksia",
     "No conversations found" : "Keskusteluja ei löytynyt",
@@ -839,7 +850,6 @@ OC.L10N.register(
     "The meeting will start soon" : "Tämä kokous alkaa pian",
     "This meeting is scheduled for {startTime}" : "Kokous on ajoitettu alkavaksi {startTime}",
     "You are currently waiting in the lobby" : "Odotat parhaillaan aulassa",
-    "None" : "Ei mitään",
     "Select microphone" : "Valitse mikrofoni",
     "No microphone available" : "Ei mikrofonia saatavilla",
     "Select camera" : "Valitse kamera",
@@ -856,12 +866,7 @@ OC.L10N.register(
     "Access to microphone was denied" : "Pääsy mikrofoniin estettiin",
     "Error while accessing microphone" : "Virhe yrittäessä käyttää mikrofonia",
     "Access to camera is only possible with HTTPS" : "Kameran käyttäminen on mahdollista vain HTTPS-yhteydellä",
-    "Media settings" : "Media-asetukset",
     "The call is being recorded." : "Tämä puhelu tallennetaan.",
-    "Call without notification" : "Puhelu ilman ilmoitusta",
-    "The conversation participants will not be notified about this call" : "Keskustelun osallistujille ei ilmoiteta tästä puhelusta",
-    "Normal call" : "Normaali puhelu",
-    "The conversation participants will be notified about this call" : "Keskustelun osallistujille ilmoitetaan tästä puhelusta",
     "Apply settings" : "Toteuta asetukset",
     "Select virtual office background" : "Valitse virtuaalinen toimistotaustakuva",
     "Select virtual home background" : "Valitse virtuaalinen kotitaustakuva",
@@ -943,10 +948,6 @@ OC.L10N.register(
     "Show all reactions" : "Näytä kaikki reaktiot",
     "Add more reactions" : "Lisää enemmän reaktioita",
     "Reactions" : "Reaktiot",
-    "Today" : "Tänään",
-    "Yesterday" : "Eilen",
-    "A week ago" : "Viikko sitten",
-    "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
     "No messages" : "Ei viestejä",
     "All messages have expired or have been deleted." : "Kaikki viestit ovat vanhentuneet tai ne on poistettu.",
     "Cancel search" : "Peruuta haku",
@@ -1127,6 +1128,7 @@ OC.L10N.register(
     "Space bar" : "Välilyönti",
     "Push to talk or push to mute" : "Paina puhuaksesi tai mykistääksesi",
     "Raise or lower hand" : "Nosta tai laske käsi",
+    "More actions" : "Lisää toimintoja",
     "Start call silently" : "Aloita puhelu hiljennettynä",
     "Start call" : "Aloita puhelu",
     "End call" : "Lopeta puhelu",
@@ -1136,8 +1138,6 @@ OC.L10N.register(
     "Send a reaction" : "Lähetä reaktio",
     "React with {reaction}" : "Reagoi käyttäen {reaction}",
     "_%n participant in call_::_%n participants in call_" : ["%n osallistuja puhelussa","%n osallistujaa puhelussa"],
-    "Disable background blur" : "Poista taustan sumennus käytöstä",
-    "Blur background" : "Sumenna tausta",
     "You are not allowed to enable screensharing" : "Sinulla ei ole oikeutta ottaa näytönjakamista käyttöön",
     "No screensharing" : "Ei näytönjakamista",
     "Screensharing options" : "Näytönjakamisen valinnat",
@@ -1149,28 +1149,18 @@ OC.L10N.register(
     "Bad sent audio and screen quality." : "Heikko lähetetyn äänen ja näytön laatu.",
     "Bad sent audio and video quality." : "Heikko lähetetyn äänen ja videon laatu.",
     "Bad sent audio quality." : "Heikko lähetetyn äänen laatu.",
+    "Disable background blur" : "Poista taustan sumennus käytöstä",
     "Disable screenshare" : "Poista käytöstä näytönjakaminen",
     "Screen sharing is not supported by your browser." : "Selaimesi ei tue näytönjakoa.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
     "Screensharing requires the page to be loaded through HTTPS." : "Näytön jakaminen vaatii sivun lataamista HTTPS-protokollalla.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
-    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
     "An error occurred while starting screensharing." : "Virhe aloitettaessa näytön jakamista.",
     "Show your screen" : "Näytä oma näyttösi",
     "Stop screensharing" : "Lopeta näytön jakaminen",
-    "Exit full screen (F)" : "Poistu koko näytön tilasta (F)",
-    "Full screen (F)" : "Koko näyttö (F)",
-    "Speaker view" : "Puhujan näkymä",
-    "Grid view" : "Ruudukkonäkymä",
-    "Raise hand" : "Nosta käsi",
-    "Raise hand (R)" : "Nosta käsi (R)",
-    "Lower hand" : "Laske käsi",
-    "Lower hand (R)" : "Laske käsi (R)",
     "Mute others" : "Mykistä muut",
-    "Toggle full screen" : "Koko näyttö päälle/pois",
     "Start recording" : "Käynnistä tallennus",
     "Set up breakout rooms" : "Määritä pienryhmätilat",
+    "Toggle full screen" : "Koko näyttö päälle/pois",
     "Remove participant {name}" : "Poista osallistuja {name}",
     "Open dialpad" : "Avaa numeronäppäimistö",
     "Select a region" : "Valitse alue",
@@ -1234,6 +1224,7 @@ OC.L10N.register(
     "Show all call recordings" : "Näytä kaikki puhelutallenteet",
     "Show all audio" : "Näytä kaikki ääni",
     "Show all other" : "Näytä kaikki muu",
+    "Default" : "Oletus",
     "Group" : "Ryhmä",
     "Team" : "Tiimi",
     "You reconnected to the call" : "Yhdistit uudelleen puheluun",
@@ -1279,7 +1270,6 @@ OC.L10N.register(
     "Please reload the page." : "Päivitä sivu.",
     "Do not disturb" : "Älä häiritse",
     "Away" : "Poissa",
-    "Default" : "Oletus",
     "Microphone {number}" : "Mikrofoni {number}",
     "Camera {number}" : "Kamera {number}",
     "Speaker {number}" : "Kaiutin {number}",
@@ -1314,9 +1304,22 @@ OC.L10N.register(
     "Filter unread mentions" : "Suodata lukemattomat maininnat",
     "Filter unread messages" : "Suodata lukemattomat viestit",
     "Refresh devices list" : "Päivitä laitelista",
+    "Media settings" : "Media-asetukset",
     "Always show preview for this conversation" : "Näytä aina esikatselu tälle keskustelulle",
+    "Call without notification" : "Puhelu ilman ilmoitusta",
+    "The conversation participants will not be notified about this call" : "Keskustelun osallistujille ei ilmoiteta tästä puhelusta",
+    "Normal call" : "Normaali puhelu",
+    "The conversation participants will be notified about this call" : "Keskustelun osallistujille ilmoitetaan tästä puhelusta",
+    "Today" : "Tänään",
+    "Yesterday" : "Eilen",
+    "A week ago" : "Viikko sitten",
+    "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
     "Close" : "Sulje",
     "Choose devices" : "Valitse laitteet",
+    "Blur background" : "Sumenna tausta",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Näytön jakaminen toimii vain Firefox-selaimen versiolla 52 tai sitä uudemmilla.",
+    "Screensharing extension is required to share your screen." : "Liitännäinen vaaditaan näytön jakamiseen.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Käytä näytön jakamiseen jotain toista selainta, kuten Firefoxia tai Chromea.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk päivitettiin, lataa sivu uudelleen",
     "An error happened when trying to share your file" : "Virhe yrittäessä jakaa tiedostoasi",
     "Failed to join the conversation. Try to reload the page." : "Liittyminen keskusteluun epäonnistui. Päivitä sivu.",
