@@ -375,6 +375,7 @@ OC.L10N.register(
     "Blocked" : "Útilokaður",
     "Active" : "Virkt",
     "Expired" : "Útrunnið",
+    "Never" : "Aldrei",
     "Language" : "Tungumál",
     "Country" : "Country",
     "Status" : "Staða",
@@ -440,6 +441,7 @@ OC.L10N.register(
     "_%n hour_::_%n hours_" : ["%n klukkustund","%n klukkustundir"],
     "Password protection" : "Verndun með lykilorði",
     "Set a password" : "Setja lykilorð",
+    "Invalid language" : "Ógilt tungumál",
     "Start time (optional)" : "Upphafstími (valfrjálst)",
     "Edit" : "Breyta",
     "More information" : "Nánari upplýsingar",
@@ -504,10 +506,6 @@ OC.L10N.register(
     "{stack} in {board}" : "{stack} á {board}",
     "Copy code block" : "Afrita kóðablokk",
     "Poll" : "Poll",
-    "Today" : "Í dag",
-    "Yesterday" : "Í gær",
-    "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "No messages" : "Engin skilaboð",
     "Create a new group conversation" : "Create a new group conversation",
     "Add participants" : "Bæta við þátttakanda",
@@ -552,19 +550,16 @@ OC.L10N.register(
     "Search" : "Search",
     "More actions" : "Fleiri aðgerðir",
     "Start call" : "Hefja samtal",
-    "Default" : "Sjálfgefið",
     "Screensharing options" : "Valkostir skjádeilingar",
     "Enable screensharing" : "Virkja skjádeilingu",
     "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
-    "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
     "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
     "Show your screen" : "Birta skjáinn þinn",
     "Stop screensharing" : "Hætta skjádeilingu",
     "Keep" : "Halda",
     "Select a region" : "Veldu svæði",
     "Submit" : "Senda inn",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Duplicate session" : "Duplicate session",
     "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
     "Talk conversation" : "Samtal í Talk-spjalli",
@@ -581,6 +576,7 @@ OC.L10N.register(
     "Audio" : "Hljóð",
     "Other" : "Annað",
     "Show all files" : "Sýna allar skrár",
+    "Default" : "Sjálfgefið",
     "Group" : "Hópur",
     "Team" : "Teymi",
     "Error while sharing file" : "Villa við deilingu skráar",
@@ -606,6 +602,12 @@ OC.L10N.register(
     "Click the button below to join." : "Smelltu á hnappinn hér fyrir neðan til að taka þátt.",
     "Join »%s«" : "Taka þátt í »%s«",
     "{user} invited you to a private conversation" : "{user} bauð þér að taka þátt í einkasímtali",
-    "Close" : "Loka"
+    "Today" : "Í dag",
+    "Yesterday" : "Í gær",
+    "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
+    "Close" : "Loka",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
+    "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
