@@ -15,6 +15,7 @@ OC.L10N.register(
     "Guest" : "Viesis",
     "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Viens pret vienu sarunas tagad ir pastāvīgas, un tās vairs nevar nejauši pārveidot par kopu sarunām. Kā arī, kad viens no dalībniekiem pamet sarunu, tā vairs netiek automātiski izdzēsta. Tikai ja abi dalībnieki izies, saruna tiks izdzēsta no servera",
     "- In the sidebar you can now find an overview of the latest shared items" : "- Sānu joslā tagad var atrast pēdējo kopīgoto vienumu pārskatu",
+    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Saruna **Piezīme sev** ir izmantojama, lai veiktu piezīmes un kopīgotu informāciju starp savām ierīcēm",
     "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Sapulces uzlabotas ar viesu, kuri uzaicināti e-pastā, atpazīšanu, dalībnieku saraksta ievietošanu, aptauju melnraksti un dalībnieku sarakstu lejupielādēšanu.",
     "Talk updates ✅" : "Talk atjauninājumi ✅",
     "{actor} created the conversation" : "{actor} izveidoja sarunu",
@@ -104,6 +105,9 @@ OC.L10N.register(
     "Avatar image is not square" : "Avatar attēls nav kvadrāts",
     "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nepareizi uzvedās. Lūgums atgriezties vēlāk.",
     "Failed to delete the account because the trial server is unreachable. Please check back later." : "Neizdevās izdzēst kontu, jo pārbaudes serveris nav sasniedzams. Lūgums atgriezties vēlāk.",
+    "Note to self" : "Piezīme sev",
+    "Let's get started!" : "Sāksim!",
+    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## Sarunas iestatījumu pārvaldīšana\n\nSarunas izvēlnē var piekļūt dažādiem iestatījumiem, lai pārvaldītu savas sarunas. Piemēram:\n* labot informāciju par sarunām;\n* pārvaldīt paziņojumus;\n* pielietot dažādas satura pārraudzības kārtulas;\n* konfigurēt piekļuvi un drošību;\n* iespējot robotprogrammatūru;\n* un vēl.",
     "Andorra" : "Andora",
     "United Arab Emirates" : "Apvienotie Arābu Emirāti",
     "Afghanistan" : "Afganistāna",
@@ -367,10 +371,13 @@ OC.L10N.register(
     "Enable encryption" : "Ieslēgt šifrēšanu",
     "Pending" : "Gaida",
     "Error" : "Kļūda",
+    "Never" : "Nekad",
     "Language" : "Valoda",
     "Country" : "Valsts",
     "Status" : "Status",
     "Created at" : "Izveidots plkst.",
+    "Yes" : "Jā",
+    "No" : "Nē",
     "Validate SSL certificate" : "Pārbaudīt SSL sertifikātu",
     "Delete this server" : "Izdzēst šo serveri",
     "Test this server" : "Testēt šo serveri",
@@ -411,6 +418,7 @@ OC.L10N.register(
     "Show screen" : "Rādīt ekrānu",
     "Collapse" : "Sakļaut",
     "Favorite" : "Izlasē",
+    "Manage the list of banned users in this conversation." : "Pārvaldīt šīs sarunas liegto lietotāju sarakstu.",
     "Date:" : "Datums:",
     "Hide details" : "Paslēpt informāciju",
     "Show details" : "Rādīt informāciju",
@@ -424,8 +432,6 @@ OC.L10N.register(
     "Setup overview" : "Uzstādīšanas pārskats",
     "Leave conversation" : "Atstāt sarunu",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
-    "No" : "Nē",
-    "Yes" : "Jā",
     "Delete conversation" : "Izdzēst sarunu",
     "_%n hour_::_%n hours_" : ["%n stundu","%n stunda","%n stundas"],
     "Password protection" : "Password protection",
@@ -454,18 +460,17 @@ OC.L10N.register(
     "Files" : "Datnes",
     "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
     "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
+    "Message forwarded to \"Note to self\"" : "Ziņojums pārvirzīts uz “Piezīme sev”",
+    "Error while forwarding message to \"Note to self\"" : "Kļūda ziņojuma pārvirzīšanas uz “Piezīme sev” laikā",
     "Reply" : "Atbildēt",
     "Go to file" : "Doties uz datni",
     "Translate" : "Tulkot",
     "Dismiss" : "Atmest",
     "Contact" : "Kontaktpersona",
-    "Today" : "Šodien",
-    "Yesterday" : "Vakar",
-    "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "File to share" : "Kopīgojamā datne",
     "Upload from device" : "Augšupielādēt no ierīces",
     "New file" : "Jauna datne",
+    "Add more files" : "Pievienot vairāk datņu",
     "Send" : "Sūtīt",
     "Settings" : "Iestatījumi",
     "moderator" : "satura pārraudzītājs",
@@ -495,15 +500,11 @@ OC.L10N.register(
     "Start call" : "Sākt zvanu",
     "All tasks done!" : "Visi uzdevumi paveikti.",
     "_{done} of %n task_::_{done} of %n tasks_" : ["{done} no %n uzdevumiem","{done} no %n uzdevuma","{done} no %n uzdevumiem"],
-    "Default" : "Noklusējuma",
     "You are not allowed to enable screensharing" : "Nav ļauts iespējot ekrāna kopīgošanu",
     "No screensharing" : "Nav ekrāna kopīgošanas",
     "Screensharing options" : "Ekrāna kopīgošanas iespējas",
     "Enable screensharing" : "Iespējot ekrāna kopīgošanu",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekrāna kopīgošanai ir nepieciešams lapu ielādēt ar HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
-    "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu.",
     "An error occurred while starting screensharing." : "Ekrāna kopīgošanas uzsākšanas laikā atgadījās kļūda.",
     "Show your screen" : "Rādīt savu ekrānu",
     "Stop screensharing" : "Apturēt ekrāna kopīgošanu",
@@ -511,8 +512,9 @@ OC.L10N.register(
     "Open Calendar" : "Atvērt kalendāru",
     "Would you like to delete this conversation?" : "Vai izdzēst šo sarunu?",
     "Keep" : "Paturēt",
-    "Select a region" : "Izvēlieties reģionu",
+    "Select a region" : "Atlasīt apgabalu",
     "Submit" : "Iesniegt",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Duplicate session" : "Pavairot sesiju",
     "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
     "User" : "Lietotājs",
@@ -525,7 +527,9 @@ OC.L10N.register(
     "Polls" : "Aptaujas",
     "Audio" : "Audio",
     "Other" : "Cits",
+    "Show all files" : "Parādīt visas datnes",
     "Show all polls" : "Parādīt visas aptaujas",
+    "Default" : "Noklusējuma",
     "Group" : "Grupa",
     "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
@@ -533,7 +537,7 @@ OC.L10N.register(
     "Please reload the page." : "Lūgums pārlādēt lapu",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, lūgums palaist savu pārlūku no jauna, jo ir skaņas un video atteice",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
-    "Please move your setup to HTTPS" : "Lūdzu, pārvietojiet iestatījumu uz HTTPS",
+    "Please move your setup to HTTPS" : "Lūgums pārvietot serveri uz HTTPS",
     "Access to microphone & camera was denied" : "Tika noraidīta piekļuve mikrofonam un kamerai",
     "WebRTC is not supported in your browser" : "Pārlūkā netiek atbalstīts WebRTC",
     "Please use a different browser like Firefox or Chrome" : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome",
@@ -553,6 +557,12 @@ OC.L10N.register(
     "Click the button below to join." : "Jāklikšķina uz zemāk esošās pogas, lai pievienotos.",
     "Join »%s«" : "Pievienoties »%s«",
     "{user} invited you to a private conversation" : "{user} uzaicināja Tevi uz privātu sarunu",
-    "Close" : "Aizvērt"
+    "Today" : "Šodien",
+    "Yesterday" : "Vakar",
+    "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
+    "Close" : "Aizvērt",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
+    "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
