@@ -472,10 +472,13 @@ OC.L10N.register(
     "Error" : "Eroare",
     "Blocked" : "Blocat",
     "Active" : "Activ",
+    "Never" : "Niciodată",
     "Language" : "Limba",
     "Country" : "Țară",
     "Status" : "Stare",
     "Created at" : "Creat la",
+    "Yes" : "Da",
+    "No" : "Nu",
     "Downloading …" : "Se descarcă ...",
     "Failed" : "Eșuat",
     "OK" : "OK",
@@ -499,6 +502,14 @@ OC.L10N.register(
     "Search participants" : "Caută participanți",
     "No results" : "Niciun rezultat",
     "Done" : "Realizat",
+    "Raise hand" : "Ridică mâna",
+    "Raise hand (R)" : "Ridică mâna (R)",
+    "Lower hand" : "Coboară mâna",
+    "Lower hand (R)" : "Coboară mâna (R)",
+    "Exit full screen (F)" : "Ieșire din ecran complet (F)",
+    "Full screen (F)" : "Ecran complet (F)",
+    "Speaker view" : "Vizualizare vorbitor",
+    "Grid view" : "Afișare în grilă",
     "This conversation is read-only" : "Această conversație este read-only",
     "{nickName} raised their hand." : "{nickName} a ridicat mâna.",
     "A participant raised their hand." : "Un participant a ridicat mâna.",
@@ -516,6 +527,7 @@ OC.L10N.register(
     "Mute audio (M)" : "Oprire sunet (M)",
     "Unmute audio" : "Reactivare sunet",
     "Unmute audio (M)" : "Reactivare sunet (M)",
+    "None" : "Niciuna",
     "Access to camera was denied" : "Accesul la cameră a fost respins",
     "Error while accessing camera: It is likely in use by another program" : "Eroare la accesul la cameră: Poate este folosită de alt program",
     "Error while accessing camera" : "Eroare la accesarea camerei",
@@ -572,8 +584,6 @@ OC.L10N.register(
     "Error while clearing chat history" : "Eroare la ștergerea istoricului de chat",
     "Leave conversation" : "Părăsiți conversația",
     "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Odată ce ați părăsit o conversație, pentru a vă realătura aveți nevoie de o invitație. Conversațiile deschise pot fi accesate oricând.",
-    "No" : "Nu",
-    "Yes" : "Da",
     "Delete conversation" : "Șterge conversația",
     "Permanently delete this conversation." : "Șterge permanent conversația",
     "Delete chat messages" : "Șterge mesajele de chat",
@@ -631,7 +641,6 @@ OC.L10N.register(
     "Users and groups" : "Utilizatori și grupuri",
     "Other sources" : "Alte surse",
     "The meeting will start soon" : "Întâlnirea va începe în curând",
-    "None" : "Niciuna",
     "Devices" : "Dispozitive",
     "Calls are not supported in your browser" : "Apelurile video nu sunt suportate de browser",
     "Access to microphone was denied" : "Accesul la microfon a fost respins",
@@ -658,9 +667,6 @@ OC.L10N.register(
     "Dismiss" : "Elimină",
     "Contact" : "Contact",
     "{stack} in {board}" : "{stack} în {board}",
-    "Today" : "Azi",
-    "Yesterday" : "Ieri",
-    "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
     "No messages" : "Niciun mesaj",
     "Cancel search" : "Renunță la căutare",
     "All set, the conversation \"{conversationName}\" was created." : "Totul a fost configurat, conversația \"{conversationName}\" a fost creată.",
@@ -763,6 +769,7 @@ OC.L10N.register(
     "Space bar" : "Bara de spațiu",
     "Push to talk or push to mute" : "Apăsați pentru a vorbi sau pentru a suprima microfonul",
     "Raise or lower hand" : "Ridicare sau coborâre mână",
+    "More actions" : "Mai multe acțiuni",
     "Start call silently" : "Pornește videoconferința fără sunet",
     "Start call" : "Pornește videoconferința",
     "End call" : "Închidere videoconferință",
@@ -771,8 +778,6 @@ OC.L10N.register(
     "The call has been running for one hour." : "Videoconferința durează de o oră",
     "Send a reaction" : "Trimite o reacție",
     "React with {reaction}" : "Reacționează cu {reaction}",
-    "Disable background blur" : "Dezactivează blurarea fundalului",
-    "Blur background" : "Blurează fundalul",
     "You are not allowed to enable screensharing" : "Nu aveți permisiunea de partajare a ecranului",
     "No screensharing" : "Nicio partajare de ecran",
     "Screensharing options" : "Opțiuni pentru partajarea ecranului",
@@ -784,20 +789,12 @@ OC.L10N.register(
     "Bad sent audio and screen quality." : "Calitate proastă audio și imagine.",
     "Bad sent audio and video quality." : "Calitate proastă audio și video.",
     "Bad sent audio quality." : "Calitate audio proastă.",
+    "Disable background blur" : "Dezactivează blurarea fundalului",
     "Disable screenshare" : "Dezactivează partajarea ecranului",
     "Screen sharing is not supported by your browser." : "Partajarea ecranului nu e posibilă în acest browser.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului.",
     "An error occurred while starting screensharing." : "Eroare la partajarea ecranului.",
     "Show your screen" : "Prezentați ecranul",
     "Stop screensharing" : "Oprește partajarea ecranului",
-    "Exit full screen (F)" : "Ieșire din ecran complet (F)",
-    "Full screen (F)" : "Ecran complet (F)",
-    "Speaker view" : "Vizualizare vorbitor",
-    "Grid view" : "Afișare în grilă",
-    "Raise hand" : "Ridică mâna",
-    "Raise hand (R)" : "Ridică mâna (R)",
-    "Lower hand" : "Coboară mâna",
-    "Lower hand (R)" : "Coboară mâna (R)",
     "Mute others" : "Închide microfonul celorlalți",
     "Toggle full screen" : "Comută în ecran complet",
     "Remove participant {name}" : "Elimină participantul {name}",
@@ -832,6 +829,7 @@ OC.L10N.register(
     "Show all locations" : "Arată toate locațiile",
     "Show all audio" : "Arată audio",
     "Show all other" : "Arată celelalte",
+    "Default" : "Implicit",
     "Group" : "Grup",
     "Team" : "Echipă",
     "You reconnected to the call" : "V-ați reconectat",
@@ -875,7 +873,6 @@ OC.L10N.register(
     "Please reload the page." : "Te rugăm să reîncarci pagina.",
     "Do not disturb" : "Nu deranja",
     "Away" : "Plecat",
-    "Default" : "Implicit",
     "Microphone {number}" : "Microfon {number}",
     "Speaker {number}" : "Vorbitor {number}",
     "Access to microphone & camera was denied" : "Accesul la microfon și cameră a fost refuzat",
@@ -895,8 +892,13 @@ OC.L10N.register(
     "Copy conversation link" : "Copiază linkul conversației",
     "Filter unread mentions" : "Filtrează mențiunile necitite",
     "Filter unread messages" : "Filtrează mesajele necitite",
+    "Today" : "Azi",
+    "Yesterday" : "Ieri",
+    "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
     "Close" : "Închide",
     "Choose devices" : "Selectați dispozitivele",
+    "Blur background" : "Blurează fundalul",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Folosiți un alt browser precum Firefox și Chrome pentru partajarea ecranului.",
     "An error happened when trying to share your file" : "Eroare la încercarea de partajare a fișierului",
     "Failed to join the conversation. Try to reload the page." : "Eroare la încercarea de participare la conversație. Încercați să reîncărcați pagina. "
 },
