@@ -31,10 +31,13 @@ OC.L10N.register(
     "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
     "Pending" : "รอดำเนินการ",
     "Error" : "ข้อผิดพลาด",
+    "Never" : "ไม่เคย",
     "Language" : "ภาษา",
     "Country" : "ประเทศ",
     "Status" : "สถานะ",
     "Created at" : "สร้างเมื่อ",
+    "Yes" : "ใช่",
+    "No" : "ไม่ตกลง",
     "OK" : "ตกลง",
     "Confirm" : "ยืนยัน",
     "Reset" : "รีเซ็ต",
@@ -55,8 +58,6 @@ OC.L10N.register(
     "Choose" : "เลือก",
     "Restricted" : "ถูกจำกัด",
     "Personal" : "ส่วนตัว",
-    "No" : "ไม่ตกลง",
-    "Yes" : "ใช่",
     "Password protection" : "ป้องกันด้วยรหัสผ่าน",
     "Edit" : "แก้ไข",
     "Delete" : "ลบ",
@@ -64,6 +65,7 @@ OC.L10N.register(
     "Log in" : "เข้าสู่ระบบ",
     "Remove from favorites" : "เอาออกจากรายการโปรด",
     "Add to favorites" : "เพิ่มในรายการโปรด",
+    "Home" : "หน้าหลัก",
     "Users" : "ผู้ใช้",
     "Groups" : "กลุ่ม",
     "Devices" : "อุปกรณ์",
@@ -73,9 +75,6 @@ OC.L10N.register(
     "Reply" : "ตอบกลับ",
     "Translate" : "แปลภาษา",
     "Dismiss" : "ปิดทิ้ง",
-    "Today" : "วันนี้",
-    "Yesterday" : "เมื่อวาน",
-    "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
     "Add participants" : "เพิ่มผู้เข้าร่วม",
     "New file" : "ไฟล์ใหม่",
     "Blank" : "ว่าง",
@@ -93,7 +92,6 @@ OC.L10N.register(
     "Privacy" : "ความเป็นส่วนตัว",
     "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Search" : "ค้นหา",
-    "Default" : "ค่าเริ่มต้น",
     "Keep" : "เก็บ",
     "Submit" : "ส่ง",
     "User" : "ผู้ใช้",
@@ -105,6 +103,7 @@ OC.L10N.register(
     "Locations" : "สถานที่",
     "Audio" : "เสียง",
     "Other" : "อื่น ๆ",
+    "Default" : "ค่าเริ่มต้น",
     "Group" : "กลุ่ม",
     "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
     "Do not disturb" : "ห้ามรบกวน",
@@ -115,6 +114,9 @@ OC.L10N.register(
     "__language_name__" : "ไทย",
     "Tasks" : "งาน",
     "Notes" : "โน้ต",
+    "Today" : "วันนี้",
+    "Yesterday" : "เมื่อวาน",
+    "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
     "Close" : "ปิด"
 },
 "nplurals=1; plural=0;");
