@@ -29,6 +29,7 @@ use OCA\Talk\Service\AttachmentService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\PollService;
 use OCA\Talk\Service\RoomService;
+use OCA\Talk\Service\ThreadService;
 use OCA\Talk\Share\RoomShareProvider;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -112,6 +113,7 @@ class ChatManager {
 		private ParticipantService $participantService,
 		private RoomService $roomService,
 		private PollService $pollService,
+		protected ThreadService $threadService,
 		private Notifier $notifier,
 		ICacheFactory $cacheFactory,
 		protected ITimeFactory $timeFactory,
@@ -148,6 +150,7 @@ class ChatManager {
 		?IComment $replyTo = null,
 		bool $shouldSkipLastMessageUpdate = false,
 		bool $silent = false,
+		int $threadId = 0,
 	): IComment {
 		if ($chat->isFederatedConversation()) {
 			$e = new MessagingNotAllowedException();
@@ -166,6 +169,8 @@ class ChatManager {
 		}
 		if ($replyTo !== null) {
 			$comment->setParentId($replyTo->getId());
+		} elseif ($threadId !== 0) {
+			$comment->setParentId((string)$threadId);
 		}
 
 		$messageDecoded = json_decode($message, true);
@@ -189,16 +194,32 @@ class ChatManager {
 		$this->setMessageExpiration($chat, $comment);
 
 		$shouldFlush = $this->notificationManager->defer();
+		$threadId = 0;
 
 		$event = new BeforeSystemMessageSentEvent($chat, $comment, silent: $silent, parent: $replyTo, skipLastActivityUpdate: $shouldSkipLastMessageUpdate);
 		$this->dispatcher->dispatchTyped($event);
 		try {
 			$this->commentsManager->save($comment);
+			$threadId = (int)$comment->getTopmostParentId();
 
 			if (!$shouldSkipLastMessageUpdate) {
 				// Update last_message
 				$this->roomService->setLastMessage($chat, $comment);
 				$this->unreadCountCache->clear($chat->getId() . '-');
+
+				if ($threadId !== 0) {
+					$isThread = $this->threadService->updateLastMessageInfoAfterReply($threadId, (int)$comment->getId(), $chat->getId());
+					if ($isThread && $actorType === Attendee::ACTOR_USERS) {
+						try {
+							// Add to subscribed threads list
+							$participant = $this->participantService->getParticipant($chat, $actorId);
+							$this->threadService->ensureIsThreadAttendee($participant->getAttendee(), $threadId);
+						} catch (ParticipantNotFoundException) {
+						}
+					} elseif (!$isThread) {
+						$threadId = 0;
+					}
+				}
 			}
 
 			if ($sendNotifications) {
@@ -213,7 +234,7 @@ class ChatManager {
 						$federatedUsersDirectlyMentioned = $this->notifier->getMentionedCloudIds($captionComment);
 					}
 					if ($replyTo instanceof IComment) {
-						$alreadyNotifiedUsers = $this->notifier->notifyReplyToAuthor($chat, $comment, $replyTo, $silent);
+						$alreadyNotifiedUsers = $this->notifier->notifyReplyToAuthor($chat, $comment, $replyTo, $silent, $threadId);
 						if ($replyTo->getActorType() === Attendee::ACTOR_USERS) {
 							$usersDirectlyMentioned[] = $replyTo->getActorId();
 						} elseif ($replyTo->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
@@ -222,7 +243,7 @@ class ChatManager {
 					}
 				}
 
-				$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $captionComment ?? $comment, $alreadyNotifiedUsers, $silent);
+				$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $captionComment ?? $comment, $alreadyNotifiedUsers, $silent, threadId: $threadId);
 				if (!empty($alreadyNotifiedUsers)) {
 					$userIds = array_column($alreadyNotifiedUsers, 'id');
 					$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_USERS, $userIds, (int)$comment->getId(), $usersDirectlyMentioned);
@@ -250,6 +271,9 @@ class ChatManager {
 		} catch (NotFoundException $e) {
 		}
 		$this->cache->remove($chat->getToken());
+		if ($threadId !== 0) {
+			$this->cache->remove($chat->getToken() . '/' . $threadId);
+		}
 
 		if ($shouldFlush) {
 			$this->notificationManager->flush();
@@ -276,10 +300,12 @@ class ChatManager {
 		$comment->setCreationDateTime($this->timeFactory->getDateTime());
 		$comment->setVerb(self::VERB_MESSAGE); // Has to be 'comment', so it counts as unread message
 
+		$threadId = 0;
 		$event = new BeforeSystemMessageSentEvent($chat, $comment);
 		$this->dispatcher->dispatchTyped($event);
 		try {
 			$this->commentsManager->save($comment);
+			$threadId = (int)$comment->getTopmostParentId();
 
 			// Update last_message
 			$this->roomService->setLastMessage($chat, $comment);
@@ -290,6 +316,9 @@ class ChatManager {
 		} catch (NotFoundException $e) {
 		}
 		$this->cache->remove($chat->getToken());
+		if ($threadId !== 0) {
+			$this->cache->remove($chat->getToken() . '/' . $threadId);
+		}
 
 		return $comment;
 	}
@@ -314,11 +343,13 @@ class ChatManager {
 			Message::METADATA_CAN_MENTION_ALL => true,
 		];
 		$comment->setMetaData($metaData);
+		$threadId = 0;
 
 		$event = new BeforeSystemMessageSentEvent($chat, $comment);
 		$this->dispatcher->dispatchTyped($event);
 		try {
 			$this->commentsManager->save($comment);
+			$threadId = (int)$comment->getTopmostParentId();
 
 			// Update last_message
 			$this->roomService->setLastMessage($chat, $comment);
@@ -329,6 +360,9 @@ class ChatManager {
 		} catch (NotFoundException $e) {
 		}
 		$this->cache->remove($chat->getToken());
+		if ($threadId !== 0) {
+			$this->cache->remove($chat->getToken() . '/' . $threadId);
+		}
 
 		return $comment;
 	}
@@ -351,6 +385,7 @@ class ChatManager {
 		string $referenceId = '',
 		bool $silent = false,
 		bool $rateLimitGuestMentions = true,
+		int $threadId = 0,
 	): IComment {
 		if ($chat->isFederatedConversation()) {
 			$e = new MessagingNotAllowedException();
@@ -367,6 +402,8 @@ class ChatManager {
 
 		if ($replyTo instanceof IComment) {
 			$comment->setParentId($replyTo->getId());
+		} elseif ($threadId !== 0) {
+			$comment->setParentId((string)$threadId);
 		}
 
 		$referenceId = trim(substr($referenceId, 0, 64));
@@ -399,12 +436,24 @@ class ChatManager {
 		$event = new BeforeChatMessageSentEvent($chat, $comment, $participant, $silent, $replyTo);
 		$this->dispatcher->dispatchTyped($event);
 
+		$threadId = 0;
 		$shouldFlush = $this->notificationManager->defer();
 		try {
 			$this->commentsManager->save($comment);
+			$messageId = (int)$comment->getId();
+			$threadId = (int)$comment->getTopmostParentId();
+			if ($threadId !== 0) {
+				$isThread = $this->threadService->updateLastMessageInfoAfterReply($threadId, $messageId, $chat->getId());
+				if (!$isThread) {
+					$threadId = 0;
+				} elseif ($participant instanceof Participant) {
+					// Add to subscribed threads list
+					$this->threadService->ensureIsThreadAttendee($participant->getAttendee(), $threadId);
+				}
+			}
 
 			if ($participant instanceof Participant) {
-				$this->participantService->updateLastReadMessage($participant, (int)$comment->getId());
+				$this->participantService->updateLastReadMessage($participant, $messageId);
 			}
 
 			// Update last_message
@@ -421,7 +470,7 @@ class ChatManager {
 			$usersDirectlyMentioned = $this->notifier->getMentionedUserIds($comment);
 			$federatedUsersDirectlyMentioned = $this->notifier->getMentionedCloudIds($comment);
 			if ($replyTo instanceof IComment) {
-				$alreadyNotifiedUsers = $this->notifier->notifyReplyToAuthor($chat, $comment, $replyTo, $silent);
+				$alreadyNotifiedUsers = $this->notifier->notifyReplyToAuthor($chat, $comment, $replyTo, $silent, $threadId);
 				if ($replyTo->getActorType() === Attendee::ACTOR_USERS) {
 					$usersDirectlyMentioned[] = $replyTo->getActorId();
 				} elseif ($replyTo->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
@@ -429,7 +478,7 @@ class ChatManager {
 				}
 			}
 
-			$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $comment, $alreadyNotifiedUsers, $silent, $participant);
+			$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $comment, $alreadyNotifiedUsers, $silent, $participant, threadId: $threadId);
 			if (!empty($alreadyNotifiedUsers)) {
 				$userIds = array_column($alreadyNotifiedUsers, 'id');
 				$this->participantService->markUsersAsMentioned($chat, Attendee::ACTOR_USERS, $userIds, (int)$comment->getId(), $usersDirectlyMentioned);
@@ -446,6 +495,9 @@ class ChatManager {
 		} catch (NotFoundException $e) {
 		}
 		$this->cache->remove($chat->getToken());
+		if ($threadId !== 0) {
+			$this->cache->remove($chat->getToken() . '/' . $threadId);
+		}
 		if ($shouldFlush) {
 			$this->notificationManager->flush();
 		}
@@ -485,8 +537,8 @@ class ChatManager {
 
 		$attendee = $participant->getAttendee();
 
-		if (!$participant->hasModeratorPermissions(false) &&
-			!($attendee->getActorType() === Attendee::ACTOR_USERS && $attendee->getActorId() === $share->getShareOwner())) {
+		if (!$participant->hasModeratorPermissions(false)
+			&& !($attendee->getActorType() === Attendee::ACTOR_USERS && $attendee->getActorId() === $share->getShareOwner())) {
 			// Only moderators or the share owner can delete the share
 			return;
 		}
@@ -708,6 +760,7 @@ class ChatManager {
 		$this->participantService->resetChatDetails($chat);
 
 		$this->pollService->deleteByRoomId($chat->getId());
+		$this->threadService->deleteByRoom($chat);
 
 		return $this->addSystemMessage(
 			$chat,
@@ -756,6 +809,30 @@ class ChatManager {
 		return $comment;
 	}
 
+	/**
+	 * @param Room $chat
+	 * @param string $messageId
+	 * @return IComment
+	 * @throws NotFoundException
+	 */
+	public function getTopMostComment(Room $chat, string $messageId): IComment {
+		if ($chat->isFederatedConversation()) {
+			throw new InvalidRoomException('Can not call ChatManager::getTopMostComment() with a federated chat.');
+		}
+
+		$comment = $this->commentsManager->get($messageId);
+
+		if ($comment->getObjectType() !== 'chat' || $comment->getObjectId() !== (string)$chat->getId()) {
+			throw new NotFoundException('Message not found in the right context');
+		}
+
+		if ($comment->getTopmostParentId() !== '0') {
+			$comment = $this->getComment($chat, $comment->getTopmostParentId());
+		}
+
+		return $comment;
+	}
+
 	public function getLastReadMessageFromLegacy(Room $chat, IUser $user): int {
 		$marker = $this->commentsManager->getReadMark('chat', (string)$chat->getId(), $user);
 		if ($marker === null) {
@@ -802,8 +879,17 @@ class ChatManager {
 	 *                    creation date and message are relevant), or an empty array if the
 	 *                    timeout expired.
 	 */
-	public function getHistory(Room $chat, int $offset, int $limit, bool $includeLastKnown): array {
-		return $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'desc', $limit, $includeLastKnown);
+	public function getHistory(Room $chat, int $offset, int $limit, bool $includeLastKnown, int $threadId = 0): array {
+		return $this->commentsManager->getCommentsWithVerbForObjectSinceComment(
+			'chat',
+			(string)$chat->getId(),
+			[],
+			$offset,
+			'desc',
+			$limit,
+			$includeLastKnown,
+			$threadId !== 0 ? (string)$threadId : '',
+		);
 	}
 
 	/**
@@ -841,51 +927,40 @@ class ChatManager {
 	 * seconds. If the timeout ends a successful but empty response will be
 	 * sent.
 	 *
-	 * @param Room $chat
 	 * @param int $offset Last known message id
-	 * @param int $limit
-	 * @param int $timeout
-	 * @param IUser|null $user
-	 * @param bool $includeLastKnown
-	 * @param bool $markNotificationsAsRead (defaults to true)
 	 * @return IComment[] the messages found (only the id, actor type and id,
 	 *                    creation date and message are relevant), or an empty array if the
 	 *                    timeout expired.
 	 */
-	public function waitForNewMessages(Room $chat, int $offset, int $limit, int $timeout, ?IUser $user, bool $includeLastKnown, bool $markNotificationsAsRead = true): array {
+	public function waitForNewMessages(Room $chat, int $offset, int $limit, int $timeout, ?IUser $user, bool $includeLastKnown, bool $markNotificationsAsRead = true, int $threadId = 0): array {
 		if ($markNotificationsAsRead && $user instanceof IUser) {
 			$this->notifier->markMentionNotificationsRead($chat, $user->getUID());
 		}
 
 		if ($this->cache instanceof NullCache
 			|| $this->cache instanceof ArrayCache) {
-			return $this->waitForNewMessagesWithDatabase($chat, $offset, $limit, $timeout, $includeLastKnown);
+			return $this->waitForNewMessagesWithDatabase($chat, $offset, $limit, $timeout, $includeLastKnown, $threadId);
 		}
 
-		return $this->waitForNewMessagesWithCache($chat, $offset, $limit, $timeout, $includeLastKnown);
+		return $this->waitForNewMessagesWithCache($chat, $offset, $limit, $timeout, $includeLastKnown, $threadId);
 	}
 
 	/**
 	 * Check the cache until we found new messages, or the timeout was reached
 	 *
-	 * @param Room $chat
-	 * @param int $offset
-	 * @param int $limit
-	 * @param int $timeout
-	 * @param bool $includeLastKnown
 	 * @return IComment[]
 	 */
-	protected function waitForNewMessagesWithCache(Room $chat, int $offset, int $limit, int $timeout, bool $includeLastKnown): array {
+	protected function waitForNewMessagesWithCache(Room $chat, int $offset, int $limit, int $timeout, bool $includeLastKnown, int $threadId): array {
 		$elapsedTime = 0;
 
-		$comments = $this->checkCacheOrDatabase($chat, $offset, $limit, $includeLastKnown);
+		$comments = $this->checkCacheOrDatabase($chat, $offset, $limit, $includeLastKnown, $threadId);
 
 		while (empty($comments) && $elapsedTime < $timeout) {
 			$this->connection->close();
 			sleep(1);
 			$elapsedTime++;
 
-			$comments = $this->checkCacheOrDatabase($chat, $offset, $limit, $includeLastKnown);
+			$comments = $this->checkCacheOrDatabase($chat, $offset, $limit, $includeLastKnown, $threadId);
 		}
 
 		return $comments;
@@ -894,27 +969,36 @@ class ChatManager {
 	/**
 	 * Check the cache for the last message id or check the database for updates
 	 *
-	 * @param Room $chat
-	 * @param int $offset
-	 * @param int $limit
-	 * @param bool $includeLastKnown
 	 * @return IComment[]
 	 */
-	protected function checkCacheOrDatabase(Room $chat, int $offset, int $limit, bool $includeLastKnown): array {
-		$cachedId = $this->cache->get($chat->getToken());
+	protected function checkCacheOrDatabase(Room $chat, int $offset, int $limit, bool $includeLastKnown, int $threadId): array {
+		$cacheKey = $chat->getToken();
+		if ($threadId !== 0) {
+			$cacheKey .= '/' . $threadId;
+		}
+		$cachedId = $this->cache->get($cacheKey);
 		if ($offset === $cachedId) {
 			// Cache hit, nothing new ¯\_(ツ)_/¯
 			return [];
 		}
 
 		// Load data from the database
-		$comments = $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
+		$comments = $this->commentsManager->getCommentsWithVerbForObjectSinceComment(
+			'chat',
+			(string)$chat->getId(),
+			[],
+			$offset,
+			'asc',
+			$limit,
+			$includeLastKnown,
+			$threadId !== 0 ? (string)$threadId : '',
+		);
 
 		if (empty($comments)) {
 			// We only write the cache when there were no new comments,
 			// otherwise it could happen that this is not the last message,
 			// but the last within $limit
-			$this->cache->set($chat->getToken(), $offset, 30);
+			$this->cache->set($cacheKey, $offset, 30);
 			return [];
 		}
 
@@ -924,23 +1008,36 @@ class ChatManager {
 	/**
 	 * Check the database for new messages until there a new messages or we exceeded the timeout
 	 *
-	 * @param Room $chat
-	 * @param int $offset
-	 * @param int $limit
-	 * @param int $timeout
-	 * @param bool $includeLastKnown
-	 * @return array
+	 * @return IComment[]
 	 */
-	protected function waitForNewMessagesWithDatabase(Room $chat, int $offset, int $limit, int $timeout, bool $includeLastKnown): array {
+	protected function waitForNewMessagesWithDatabase(Room $chat, int $offset, int $limit, int $timeout, bool $includeLastKnown, int $threadId): array {
 		$elapsedTime = 0;
 
-		$comments = $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
+		$comments = $this->commentsManager->getCommentsWithVerbForObjectSinceComment(
+			'chat',
+			(string)$chat->getId(),
+			[],
+			$offset,
+			'asc',
+			$limit,
+			$includeLastKnown,
+			$threadId !== 0 ? (string)$threadId : '',
+		);
 
 		while (empty($comments) && $elapsedTime < $timeout) {
 			sleep(1);
 			$elapsedTime++;
 
-			$comments = $this->commentsManager->getForObjectSince('chat', (string)$chat->getId(), $offset, 'asc', $limit, $includeLastKnown);
+			$comments = $this->commentsManager->getCommentsWithVerbForObjectSinceComment(
+				'chat',
+				(string)$chat->getId(),
+				[],
+				$offset,
+				'asc',
+				$limit,
+				$includeLastKnown,
+				$threadId !== 0 ? (string)$threadId : '',
+			);
 		}
 
 		return $comments;
@@ -961,6 +1058,7 @@ class ChatManager {
 		$this->attachmentService->deleteAttachmentsForRoom($chat);
 
 		$this->pollService->deleteByRoomId($chat->getId());
+		$this->threadService->deleteByRoom($chat);
 	}
 
 	/**
