@@ -12,9 +12,11 @@ use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Files\Util;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
+use OCA\Talk\Model\ThreadAttendee;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCA\Talk\Service\ThreadService;
 use OCA\Talk\Webinary;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
@@ -33,11 +35,16 @@ use OCP\Notification\INotification;
  * prepares the notifications for display.
  */
 class Notifier {
+	public const PRIORITY_NONE = 0;
+	public const PRIORITY_NORMAL = 1;
+	public const PRIORITY_IMPORTANT = 2;
+
 	public function __construct(
 		private INotificationManager $notificationManager,
 		private IUserManager $userManager,
 		private IGroupManager $groupManager,
 		private ParticipantService $participantService,
+		private ThreadService $threadService,
 		private IConfig $config,
 		private ITimeFactory $timeFactory,
 		private Util $util,
@@ -62,7 +69,7 @@ class Notifier {
 	 * @return string[] Users that were mentioned
 	 * @psalm-return array<int, array{id: string, type: string, reason: string, sourceId?: string, attendee?: Attendee}>
 	 */
-	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent, ?Participant $participant = null): array {
+	public function notifyMentionedUsers(Room $chat, IComment $comment, array $alreadyNotifiedUsers, bool $silent, ?Participant $participant = null, ?int $threadId = null): array {
 		$usersToNotify = $this->getUsersToNotify($chat, $comment, $alreadyNotifiedUsers, $participant);
 
 		if (!$usersToNotify) {
@@ -71,13 +78,14 @@ class Notifier {
 
 		$shouldFlush = false;
 		if (!$silent) {
-			$notification = $this->createNotification($chat, $comment, 'mention');
+			$notification = $this->createNotification($chat, $comment, 'mention', threadId: $threadId);
 			$parameters = $notification->getSubjectParameters();
 			$shouldFlush = $this->notificationManager->defer();
 		}
 
 		foreach ($usersToNotify as $mentionedUser) {
-			if ($this->shouldMentionedUserBeNotified($mentionedUser['id'], $comment, $chat, $mentionedUser['attendee'] ?? null)) {
+			$shouldMentionedUserBeNotified = $this->shouldMentionedUserBeNotified($mentionedUser['id'], $comment, $chat, $mentionedUser['attendee'] ?? null);
+			if ($shouldMentionedUserBeNotified !== self::PRIORITY_NONE) {
 				if (!$silent) {
 					$notification->setUser($mentionedUser['id']);
 					if (isset($mentionedUser['reason'])) {
@@ -87,6 +95,7 @@ class Notifier {
 					} else {
 						$notification->setSubject('mention', $parameters);
 					}
+					$notification->setPriorityNotification($shouldMentionedUserBeNotified === self::PRIORITY_IMPORTANT);
 					$this->notificationManager->notify($notification);
 				}
 				$alreadyNotifiedUsers[] = $mentionedUser;
@@ -194,7 +203,7 @@ class Notifier {
 	 * @return array[] Actor that was replied to
 	 * @psalm-return array<int, array{id: string, type: string, reason: string}>
 	 */
-	public function notifyReplyToAuthor(Room $chat, IComment $comment, IComment $replyTo, bool $silent): array {
+	public function notifyReplyToAuthor(Room $chat, IComment $comment, IComment $replyTo, bool $silent, ?int $threadId = null): array {
 		if ($replyTo->getActorType() !== Attendee::ACTOR_USERS && $replyTo->getActorType() !== Attendee::ACTOR_FEDERATED_USERS) {
 			// No reply notification when the replyTo-author was not a user or federated user
 			return [];
@@ -210,13 +219,15 @@ class Notifier {
 			];
 		}
 
-		if (!$this->shouldMentionedUserBeNotified($replyTo->getActorId(), $comment, $chat)) {
+		$shouldMentionedUserBeNotified = $this->shouldMentionedUserBeNotified($replyTo->getActorId(), $comment, $chat);
+		if ($shouldMentionedUserBeNotified === self::PRIORITY_NONE) {
 			return [];
 		}
 
 		if (!$silent) {
-			$notification = $this->createNotification($chat, $comment, 'reply');
+			$notification = $this->createNotification($chat, $comment, 'reply', threadId: $threadId);
 			$notification->setUser($replyTo->getActorId());
+			$notification->setPriorityNotification($shouldMentionedUserBeNotified === self::PRIORITY_IMPORTANT);
 			$this->notificationManager->notify($notification);
 		}
 
@@ -250,14 +261,47 @@ class Notifier {
 		}
 
 		$participants = $this->participantService->getParticipantsByNotificationLevel($chat, Participant::NOTIFY_ALWAYS);
+		$threadId = (int)$comment->getTopmostParentId();
+		/** @var array<int, ThreadAttendee> $threadAttendees */
+		$threadAttendees = [];
+		if ($threadId !== 0) {
+			$threadAttendees = $this->threadService->findAttendeesForNotificationByThreadId($threadId);
+		}
 
-		$notification = $this->createNotification($chat, $comment, 'chat');
+		// Handle participants that only subscribed with Participant::NOTIFY_ALWAYS to the thread, but not the conversation
+		$threadAttendeeIds = array_map(static fn (ThreadAttendee $threadAttendee): int => $threadAttendee->getAttendeeId(),
+			array_filter($threadAttendees, static fn (ThreadAttendee $threadAttendee): bool => $threadAttendee->getNotificationLevel() === Participant::NOTIFY_ALWAYS)
+		);
+		if (!empty($threadAttendeeIds)) {
+			$participantIds = array_map(static fn (Participant $participant): int => $participant->getAttendee()->getId(), $participants);
+			$missingParticipantIds = array_diff($threadAttendeeIds, $participantIds);
+			if (!empty($missingParticipantIds)) {
+				$missingParticipants = $this->participantService->getParticipantsByAttendeeId($chat, $missingParticipantIds);
+				if (!empty($missingParticipants)) {
+					$participants = array_merge($participants, $missingParticipants);
+				}
+			}
+		}
+
+		$notification = $this->createNotification($chat, $comment, 'chat', threadId: $threadId);
 		foreach ($participants as $participant) {
-			if (!$this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers)) {
+			$attendeeId = $participant->getAttendee()->getId();
+			$shouldParticipantBeNotified = $this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers);
+
+			if (isset($threadAttendees[$attendeeId])) {
+				$threadAttendee = $threadAttendees[$attendeeId];
+				if ($threadAttendee->getNotificationLevel() !== Participant::NOTIFY_ALWAYS) {
+					// User unsubscribed from this thread
+					continue;
+				}
+			}
+
+			if ($shouldParticipantBeNotified === self::PRIORITY_NONE) {
 				continue;
 			}
 
 			$notification->setUser($participant->getAttendee()->getActorId());
+			$notification->setPriorityNotification($shouldParticipantBeNotified === self::PRIORITY_IMPORTANT);
 			$this->notificationManager->notify($notification);
 		}
 
@@ -265,11 +309,13 @@ class Notifier {
 		if ($this->getDefaultGroupNotification() === Participant::NOTIFY_ALWAYS || $chat->getType() === Room::TYPE_ONE_TO_ONE) {
 			$participants = $this->participantService->getParticipantsByNotificationLevel($chat, Participant::NOTIFY_DEFAULT);
 			foreach ($participants as $participant) {
-				if (!$this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers)) {
+				$shouldParticipantBeNotified = $this->shouldParticipantBeNotified($participant, $comment, $alreadyNotifiedUsers);
+				if ($shouldParticipantBeNotified === self::PRIORITY_NONE) {
 					continue;
 				}
 
 				$notification->setUser($participant->getAttendee()->getActorId());
+				$notification->setPriorityNotification($shouldParticipantBeNotified === self::PRIORITY_IMPORTANT);
 				$this->notificationManager->notify($notification);
 			}
 		}
@@ -588,18 +634,24 @@ class Notifier {
 	 * Creates a notification for the given chat message comment and mentioned
 	 * user ID.
 	 */
-	private function createNotification(Room $chat, IComment $comment, string $subject, array $subjectData = [], ?IComment $reaction = null): INotification {
+	private function createNotification(Room $chat, IComment $comment, string $subject, array $subjectData = [], ?IComment $reaction = null, ?int $threadId = null): INotification {
 		$subjectData['userType'] = $reaction ? $reaction->getActorType() : $comment->getActorType();
 		$subjectData['userId'] = $reaction ? $reaction->getActorId() : $comment->getActorId();
 
+		$messageData = [
+			'commentId' => $comment->getId(),
+		];
+
+		if ($threadId !== null && $threadId !== 0) {
+			$messageData['threadId'] = $threadId;
+		}
+
 		$notification = $this->notificationManager->createNotification();
 		$notification
 			->setApp('spreed')
 			->setObject('chat', $chat->getToken())
 			->setSubject($subject, $subjectData)
-			->setMessage($comment->getVerb(), [
-				'commentId' => $comment->getId(),
-			])
+			->setMessage($comment->getVerb(), $messageData)
 			->setDateTime($reaction ? $reaction->getCreationDateTime() : $comment->getCreationDateTime());
 
 		return $notification;
@@ -617,16 +669,16 @@ class Notifier {
 	 * 3. The user must be a participant of the room
 	 * 4. The user must not be active in the room
 	 */
-	protected function shouldMentionedUserBeNotified(string $userId, IComment $comment, Room $room, ?Attendee $attendee = null): bool {
+	protected function shouldMentionedUserBeNotified(string $userId, IComment $comment, Room $room, ?Attendee $attendee = null): int {
 		if ($comment->getActorType() === Attendee::ACTOR_USERS && $userId === $comment->getActorId()) {
 			// Do not notify the user if they mentioned themselves
-			return false;
+			return self::PRIORITY_NONE;
 		}
 
 		try {
 			if (!$attendee instanceof Attendee) {
 				if (!$this->userManager->userExists($userId)) {
-					return false;
+					return self::PRIORITY_NONE;
 				}
 
 				$participant = $this->participantService->getParticipant($room, $userId, false);
@@ -635,12 +687,21 @@ class Notifier {
 				$participant = new Participant($room, $attendee, null);
 			}
 
-			if ($room->getLobbyState() !== Webinary::LOBBY_NONE &&
-				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
-				return false;
+			if ($room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+				return self::PRIORITY_NONE;
 			}
 
 			$notificationLevel = $attendee->getNotificationLevel();
+			$threadId = (int)$comment->getTopmostParentId();
+			if ($threadId !== 0) {
+				$threadAttendees = $this->threadService->findAttendeeByThreadIds($attendee, [$threadId]);
+				$threadAttendee = array_shift($threadAttendees);
+				if ($threadAttendee !== null && $threadAttendee->getNotificationLevel() !== Participant::NOTIFY_DEFAULT) {
+					$notificationLevel = $threadAttendee->getNotificationLevel();
+				}
+			}
+
 			if ($notificationLevel === Participant::NOTIFY_DEFAULT) {
 				if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 					$notificationLevel = Participant::NOTIFY_ALWAYS;
@@ -648,7 +709,14 @@ class Notifier {
 					$notificationLevel = $this->getDefaultGroupNotification();
 				}
 			}
-			return $notificationLevel !== Participant::NOTIFY_NEVER;
+			if ($notificationLevel === Participant::NOTIFY_NEVER) {
+				return self::PRIORITY_NONE;
+			}
+
+			if ($attendee->isImportant()) {
+				return self::PRIORITY_IMPORTANT;
+			}
+			return self::PRIORITY_NORMAL;
 		} catch (ParticipantNotFoundException $e) {
 			if ($room->getObjectType() === 'file' && $this->util->canUserAccessFile($room->getObjectId(), $userId)) {
 				// Users are added on mentions in file-rooms,
@@ -661,9 +729,9 @@ class Notifier {
 					'actorId' => $userId,
 					'displayName' => $userDisplayName ?? $userId,
 				]]);
-				return true;
+				return self::PRIORITY_NORMAL;
 			}
-			return false;
+			return self::PRIORITY_NONE;
 		}
 	}
 
@@ -675,35 +743,35 @@ class Notifier {
 	 * 3. The participant was not mentioned already
 	 * 4. The participant must not be active in the room
 	 *
-	 * @param Participant $participant
-	 * @param IComment $comment
-	 * @param array $alreadyNotifiedUsers
 	 * @psalm-param array<int, array{type: string, id: string, reason: string, sourceId?: string, attendee?: Attendee}> $alreadyNotifiedUsers
-	 * @return bool
 	 */
-	protected function shouldParticipantBeNotified(Participant $participant, IComment $comment, array $alreadyNotifiedUsers): bool {
+	protected function shouldParticipantBeNotified(Participant $participant, IComment $comment, array $alreadyNotifiedUsers): int {
 		if ($participant->getAttendee()->getActorType() !== Attendee::ACTOR_USERS) {
-			return false;
+			return self::PRIORITY_NONE;
 		}
 
 		$userId = $participant->getAttendee()->getActorId();
 		if ($comment->getActorType() === Attendee::ACTOR_USERS && $userId === $comment->getActorId()) {
 			// Do not notify the author
-			return false;
+			return self::PRIORITY_NONE;
 		}
 
 		$actorType = $participant->getAttendee()->getActorType();
 		foreach ($alreadyNotifiedUsers as $user) {
 			if ($user['id'] === $userId && $user['type'] === $actorType) {
-				return false;
+				return self::PRIORITY_NONE;
 			}
 		}
 
-		if ($participant->getSession() instanceof Session) {
+		if ($participant->getSession()?->getLastPing() >= $this->timeFactory->getTime() - Session::SESSION_TIMEOUT) {
 			// User is online
-			return $participant->getSession()->getLastPing() < $this->timeFactory->getTime() - Session::SESSION_TIMEOUT;
+			return self::PRIORITY_NONE;
 		}
 
-		return true;
+		if ($participant->getAttendee()->isImportant()) {
+			return self::PRIORITY_IMPORTANT;
+		}
+
+		return self::PRIORITY_NORMAL;
 	}
 }
