@@ -12,6 +12,7 @@ use OCA\Circles\CirclesManager;
 use OCA\DAV\CardDAV\PhotoCache;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Events\MessageParseEvent;
+use OCA\Talk\Events\OverwritePublicSharePropertiesEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\GuestManager;
@@ -26,6 +27,7 @@ use OCP\AppFramework\Services\IAppConfig;
 use OCP\Comments\IComment;
 use OCP\Comments\ICommentsManager;
 use OCP\EventDispatcher\Event;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\EventDispatcher\IEventListener;
 use OCP\Federation\ICloudIdManager;
 use OCP\Files\FileInfo;
@@ -82,9 +84,11 @@ class SystemMessage implements IEventListener {
 		protected IURLGenerator $url,
 		protected FilesMetadataCache $metadataCache,
 		protected Authenticator $federationAuthenticator,
+		protected IEventDispatcher $dispatcher,
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!$event instanceof MessageParseEvent) {
 			return;
@@ -140,36 +144,36 @@ class SystemMessage implements IEventListener {
 
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = isset($parsedParameters['actor']['server']) &&
-				$parsedParameters['actor']['type'] === 'user' &&
-				$this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id'] &&
-				$this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
+			$currentUserIsActor = isset($parsedParameters['actor']['server'])
+				&& $parsedParameters['actor']['type'] === 'user'
+				&& $this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id']
+				&& $this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
 		} elseif (!$participant->isGuest()) {
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user' &&
-				$participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS &&
-				$currentActorId === $parsedParameters['actor']['id'] &&
-				empty($parsedParameters['actor']['server']);
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user'
+				&& $participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS
+				&& $currentActorId === $parsedParameters['actor']['id']
+				&& empty($parsedParameters['actor']['server']);
 		} elseif ($participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS) {
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'email' &&
-				$participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'email'
+				&& $participant->getAttendee()->getActorType() === Attendee::ACTOR_EMAILS
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
 		} else {
 			$currentActorType = $participant->getAttendee()->getActorType();
 			$currentActorId = $participant->getAttendee()->getActorId();
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-				$participant->getAttendee()->getActorType() === 'guest' &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest'
+				&& $participant->getAttendee()->getActorType() === 'guest'
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
 		}
-		$cliIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-			'guest/' . Attendee::ACTOR_ID_CLI === $parsedParameters['actor']['id'];
+		$cliIsActor = $parsedParameters['actor']['type'] === 'guest'
+			&& 'guest/' . Attendee::ACTOR_ID_CLI === $parsedParameters['actor']['id'];
 
 		if ($message === 'conversation_created') {
-			$systemIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-				'guest/' . Attendee::ACTOR_ID_SYSTEM === $parsedParameters['actor']['id'];
+			$systemIsActor = $parsedParameters['actor']['type'] === 'guest'
+				&& 'guest/' . Attendee::ACTOR_ID_SYSTEM === $parsedParameters['actor']['id'];
 
 			$parsedMessage = $this->l->t('{actor} created the conversation');
 			if ($currentUserIsActor) {
@@ -568,6 +572,26 @@ class SystemMessage implements IEventListener {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You set up Matterbridge to synchronize this conversation with other chats');
 			}
+		} elseif ($message === 'thread_created') {
+			$parsedMessage = $this->l->t('{actor} created thread {title}');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You created thread {title}');
+			}
+			$parsedParameters['title'] = [
+				'type' => 'highlight',
+				'id' => 'thread/' . $parameters['thread'],
+				'name' => $parameters['title'] ?? (string)$parameters['thread'],
+			];
+		} elseif ($message === 'thread_renamed') {
+			$parsedMessage = $this->l->t('{actor} renamed thread {title}');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You renamed thread {title}');
+			}
+			$parsedParameters['title'] = [
+				'type' => 'highlight',
+				'id' => 'thread/' . $parameters['thread'],
+				'name' => $parameters['title'],
+			];
 		} elseif ($message === 'matterbridge_config_edited') {
 			$parsedMessage = $this->l->t('{actor} updated the Matterbridge configuration');
 			if ($currentUserIsActor) {
@@ -723,19 +747,19 @@ class SystemMessage implements IEventListener {
 				];
 			}
 
-			$currentUserIsActor = isset($parsedParameters['actor']['server']) &&
-				$parsedParameters['actor']['type'] === 'user' &&
-				$this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id'] &&
-				$this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
+			$currentUserIsActor = isset($parsedParameters['actor']['server'])
+				&& $parsedParameters['actor']['type'] === 'user'
+				&& $this->currentFederatedUserDetails['user'] === $parsedParameters['actor']['id']
+				&& $this->currentFederatedUserDetails['server'] === $parsedParameters['actor']['server'];
 		} elseif (!$participant->isGuest()) {
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user' &&
-				$participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'] &&
-				empty($parsedParameters['actor']['server']);
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'user'
+				&& $participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id']
+				&& empty($parsedParameters['actor']['server']);
 		} else {
-			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest' &&
-				$participant->getAttendee()->getActorType() === 'guest' &&
-				$participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
+			$currentUserIsActor = $parsedParameters['actor']['type'] === 'guest'
+				&& $participant->getAttendee()->getActorType() === 'guest'
+				&& $participant->getAttendee()->getActorId() === $parsedParameters['actor']['id'];
 		}
 
 		if ($chatMessage->getMessageType() === ChatManager::VERB_MESSAGE_DELETED) {
@@ -824,6 +848,7 @@ class SystemMessage implements IEventListener {
 				$node = $share->getNodeCacheEntry();
 			} else {
 				$node = $share->getNode();
+				$this->dispatcher->dispatchTyped(new OverwritePublicSharePropertiesEvent($share));
 			}
 
 			$name = $node->getName();
@@ -853,6 +878,7 @@ class SystemMessage implements IEventListener {
 			'permissions' => (string)$node->getPermissions(),
 			'mimetype' => $node->getMimeType(),
 			'preview-available' => $isPreviewAvailable ? 'yes' : 'no',
+			'hide-download' => $share->getHideDownload() ? 'yes' : 'no',
 		];
 
 		// If a preview is available, check if we can get the dimensions of the file from the metadata API
