@@ -24,6 +24,7 @@ use OCA\Talk\Events\LobbyModifiedEvent;
 use OCA\Talk\Events\ParticipantModifiedEvent;
 use OCA\Talk\Events\RoomCreatedEvent;
 use OCA\Talk\Events\RoomModifiedEvent;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\BreakoutRoom;
@@ -34,6 +35,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Service\NoteToSelfService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\SampleConversationsService;
+use OCA\Talk\Service\ThreadService;
 use OCA\Talk\TalkSession;
 use OCA\Talk\Webinary;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -66,11 +68,13 @@ class Listener implements IEventListener {
 		protected Manager $manager,
 		protected ParticipantService $participantService,
 		protected MessageParser $messageParser,
+		protected ThreadService $threadService,
 		protected IL10N $l,
 		protected LoggerInterface $logger,
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if ($event instanceof ARoomEvent && $event->getRoom()->isFederatedConversation()) {
 			return;
@@ -164,8 +168,8 @@ class Listener implements IEventListener {
 	}
 
 	protected function sendSystemMessageAboutConversationRenamed(RoomModifiedEvent $event): void {
-		if ($event->getOldValue() === '' ||
-			$event->getNewValue() === '') {
+		if ($event->getOldValue() === ''
+			|| $event->getNewValue() === '') {
 			return;
 		}
 
@@ -365,6 +369,7 @@ class Listener implements IEventListener {
 			return;
 		}
 		$room = $this->manager->getRoomByToken($share->getSharedWith());
+		$this->participantService->ensureOneToOneRoomIsFilled($room);
 
 		$metaData = $this->request->getParam('talkMetaData') ?? '';
 		$metaData = json_decode($metaData, true);
@@ -392,7 +397,53 @@ class Listener implements IEventListener {
 			$silent = false;
 		}
 
-		$this->sendSystemMessage($room, 'file_shared', ['share' => $share->getId(), 'metaData' => $metaData], silent: $silent);
+		$replyTo = null;
+		if (isset($metaData['replyTo'])) {
+			$replyTo = (int)$metaData['replyTo'];
+			unset($metaData['replyTo']);
+		}
+		$threadId = null;
+		if (isset($metaData['threadId'])) {
+			$threadId = (int)$metaData['threadId'];
+			unset($metaData['threadId']);
+		}
+
+		$threadTitle = '';
+		if (isset($metaData['threadTitle'])) {
+			if (is_string($metaData['threadTitle']) && trim($metaData['threadTitle']) !== '') {
+				$threadTitle = trim($metaData['threadTitle']);
+			}
+			unset($metaData['threadTitle']);
+		}
+
+		$comment = $this->sendSystemMessage(
+			$room,
+			'file_shared',
+			['share' => $share->getId(), 'metaData' => $metaData],
+			silent: $silent,
+			replyTo: $replyTo,
+			threadId: $threadId,
+		);
+		$messageId = (int)$comment->getId();
+
+		if ($threadTitle !== '' && $comment->getTopmostParentId() === '0') {
+			$thread = $this->threadService->createThread($room, $messageId, $threadTitle);
+			try {
+				// Add to subscribed threads list
+				$participant = $this->participantService->getParticipant($room, $this->getUserId());
+				$this->threadService->setNotificationLevel($participant->getAttendee(), $thread, Participant::NOTIFY_DEFAULT);
+			} catch (ParticipantNotFoundException) {
+			}
+
+			$this->sendSystemMessage(
+				$room,
+				'thread_created',
+				['thread' => $messageId, 'title' => $thread->getName()],
+				shouldSkipLastMessageUpdate: true,
+				silent: true,
+				parent: $comment,
+			);
+		}
 	}
 
 	protected function attendeesAddedEvent(AttendeesAddedEvent $event): void {
@@ -427,7 +478,18 @@ class Listener implements IEventListener {
 		}
 	}
 
-	protected function sendSystemMessage(Room $room, string $message, array $parameters = [], ?Participant $participant = null, bool $shouldSkipLastMessageUpdate = false, bool $silent = false, bool $forceSystemAsActor = false): IComment {
+	protected function sendSystemMessage(
+		Room $room,
+		string $message,
+		array $parameters = [],
+		?Participant $participant = null,
+		bool $shouldSkipLastMessageUpdate = false,
+		bool $silent = false,
+		bool $forceSystemAsActor = false,
+		?int $replyTo = null,
+		?IComment $parent = null,
+		?int $threadId = null,
+	): IComment {
 		if ($participant instanceof Participant) {
 			$actorType = $participant->getAttendee()->getActorType();
 			$actorId = $participant->getAttendee()->getActorId();
@@ -462,9 +524,7 @@ class Listener implements IEventListener {
 			$referenceId = (string)$referenceId;
 		}
 
-		$parent = null;
-		$replyTo = $parameters['metaData']['replyTo'] ?? null;
-		if ($replyTo !== null) {
+		if ($parent === null && $replyTo !== null) {
 			try {
 				$parentComment = $this->chatManager->getParentComment($room, (string)$replyTo);
 				$parentMessage = $this->messageParser->createMessage($room, $participant, $parentComment, $this->l);
@@ -474,11 +534,14 @@ class Listener implements IEventListener {
 				}
 			} catch (NotFoundException) {
 			}
-
+		} elseif ($parent === null && $threadId !== null) {
+			if (!$this->threadService->validateThread($room->getId(), $threadId)) {
+				$threadId = null;
+			}
 		}
 
 		return $this->chatManager->addSystemMessage(
-			$room, $actorType, $actorId,
+			$room, $participant, $actorType, $actorId,
 			json_encode(['message' => $message, 'parameters' => $parameters]),
 			$this->timeFactory->getDateTime(),
 			$message === 'file_shared',
@@ -486,6 +549,7 @@ class Listener implements IEventListener {
 			$parent,
 			$shouldSkipLastMessageUpdate,
 			$silent,
+			$threadId ?? 0,
 		);
 	}
 
@@ -584,12 +648,12 @@ class Listener implements IEventListener {
 		$trace = $exception->getTrace();
 
 		foreach ($trace as $step) {
-			if (isset($step['class']) && $step['class'] === NoteToSelfService::class &&
-				isset($step['function']) && $step['function'] === 'initialCreateNoteToSelfForUser') {
+			if (isset($step['class']) && $step['class'] === NoteToSelfService::class
+				&& isset($step['function']) && $step['function'] === 'initialCreateNoteToSelfForUser') {
 				return true;
 			}
-			if (isset($step['class']) && $step['class'] === NoteToSelfService::class &&
-				isset($step['function']) && $step['function'] === 'ensureNoteToSelfExistsForUser') {
+			if (isset($step['class']) && $step['class'] === NoteToSelfService::class
+				&& isset($step['function']) && $step['function'] === 'ensureNoteToSelfExistsForUser') {
 				return true;
 			}
 		}
@@ -606,8 +670,8 @@ class Listener implements IEventListener {
 		$trace = $exception->getTrace();
 
 		foreach ($trace as $step) {
-			if (isset($step['class']) && $step['class'] === SampleConversationsService::class &&
-				isset($step['function']) && $step['function'] === 'initialCreateSamples') {
+			if (isset($step['class']) && $step['class'] === SampleConversationsService::class
+				&& isset($step['function']) && $step['function'] === 'initialCreateSamples') {
 				return true;
 			}
 		}
@@ -624,8 +688,8 @@ class Listener implements IEventListener {
 		$trace = $exception->getTrace();
 
 		foreach ($trace as $step) {
-			if (isset($step['class']) && $step['class'] === NoteToSelfService::class &&
-				isset($step['function']) && $step['function'] === 'initialCreateNoteToSelfForUser') {
+			if (isset($step['class']) && $step['class'] === NoteToSelfService::class
+				&& isset($step['function']) && $step['function'] === 'initialCreateNoteToSelfForUser') {
 				return true;
 			}
 		}
