@@ -2,25 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2019 Arthur Schiwon <blizzz@arthur-schiwon.de>
- *
- * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Flow;
@@ -54,41 +37,32 @@ class Operation implements IOperation {
 		'ROOM_MENTION' => 3,
 	];
 
-	protected IL10N $l;
-	protected IURLGenerator $urlGenerator;
-	protected TalkManager $talkManager;
-	protected ParticipantService $participantService;
-	protected IUserSession $session;
-	protected ChatManager $chatManager;
-
 	public function __construct(
-		IL10N $l,
-		IURLGenerator $urlGenerator,
-		TalkManager $talkManager,
-		ParticipantService $participantService,
-		IUserSession $session,
-		ChatManager $chatManager,
+		protected IL10N $l,
+		protected IURLGenerator $urlGenerator,
+		protected TalkManager $talkManager,
+		protected ParticipantService $participantService,
+		protected IUserSession $session,
+		protected ChatManager $chatManager,
 	) {
-		$this->l = $l;
-		$this->urlGenerator = $urlGenerator;
-		$this->talkManager = $talkManager;
-		$this->participantService = $participantService;
-		$this->session = $session;
-		$this->chatManager = $chatManager;
 	}
 
+	#[\Override]
 	public function getDisplayName(): string {
 		return $this->l->t('Write to conversation');
 	}
 
+	#[\Override]
 	public function getDescription(): string {
 		return $this->l->t('Writes event information into a conversation of your choice');
 	}
 
+	#[\Override]
 	public function getIcon(): string {
 		return $this->urlGenerator->imagePath('spreed', 'app.svg');
 	}
 
+	#[\Override]
 	public function isAvailableForScope(int $scope): bool {
 		return $scope === FlowManager::SCOPE_USER;
 	}
@@ -100,16 +74,18 @@ class Operation implements IOperation {
 	 * @throws UnexpectedValueException
 	 * @since 9.1
 	 */
+	#[\Override]
 	public function validateOperation(string $name, array $checks, string $operation): void {
-		list($mode, $token) = $this->parseOperationConfig($operation);
+		[$mode, $token] = $this->parseOperationConfig($operation);
 		$this->validateOperationConfig($mode, $token, $this->getUser()->getUID());
 	}
 
+	#[\Override]
 	public function onEvent(string $eventName, Event $event, IRuleMatcher $ruleMatcher): void {
 		$flows = $ruleMatcher->getFlows(false);
 		foreach ($flows as $flow) {
 			try {
-				list($mode, $token) = $this->parseOperationConfig($flow['operation']);
+				[$mode, $token] = $this->parseOperationConfig($flow['operation']);
 				$uid = $flow['scope_actor_id'];
 				$this->validateOperationConfig($mode, $token, $uid);
 
@@ -126,6 +102,11 @@ class Operation implements IOperation {
 					continue;
 				}
 
+				if ($room->isFederatedConversation()) {
+					// Ignore conversation because it is a proxy conversation
+					continue;
+				}
+
 				$participant = $this->participantService->getParticipant($room, $uid, false);
 				if (!($participant->getPermissions() & Attendee::PERMISSIONS_CHAT)) {
 					// Ignore conversation because the user has no permissions
@@ -134,20 +115,14 @@ class Operation implements IOperation {
 
 				$this->chatManager->sendMessage(
 					$room,
-					$participant,
-					'bots',
+					null,
+					Attendee::ACTOR_BOTS,
 					$participant->getAttendee()->getActorId(),
 					$this->prepareMention($mode, $participant) . $message,
 					new \DateTime(),
-					null,
-					'',
-					false
+					rateLimitGuestMentions: false,
 				);
-			} catch (UnexpectedValueException $e) {
-				continue;
-			} catch (ParticipantNotFoundException $e) {
-				continue;
-			} catch (RoomNotFoundException $e) {
+			} catch (UnexpectedValueException|ParticipantNotFoundException|RoomNotFoundException) {
 				continue;
 			}
 		}
@@ -172,7 +147,7 @@ class Operation implements IOperation {
 			case self::MESSAGE_MODES['ROOM_MENTION']:
 				return '@all ';
 			case self::MESSAGE_MODES['SELF_MENTION']:
-				$hasWhitespace = strpos($participant->getAttendee()->getActorId(), ' ') !== false;
+				$hasWhitespace = str_contains($participant->getAttendee()->getActorId(), ' ');
 				$enclosure = $hasWhitespace ? '"' : '';
 				return '@' . $enclosure . $participant->getAttendee()->getActorId() . $enclosure . ' ';
 			case self::MESSAGE_MODES['NO_MENTION']:
@@ -216,6 +191,10 @@ class Operation implements IOperation {
 			throw new UnexpectedValueException('Room not found', $e->getCode(), $e);
 		}
 
+		if ($room->isFederatedConversation()) {
+			throw new UnexpectedValueException('Room is a proxy conversation');
+		}
+
 		if ($mode === self::MESSAGE_MODES['ROOM_MENTION']) {
 			try {
 				$participant = $this->participantService->getParticipant($room, $uid, false);
