@@ -2,30 +2,15 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2021 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Listener;
 
+use OCA\Talk\Events\AAttendeeRemovedEvent;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
-use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
 use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventListener;
@@ -36,20 +21,15 @@ use OCP\IConfig;
  * @template-implements IEventListener<Event>
  */
 class GroupDeletedListener implements IEventListener {
-	private IConfig $config;
-	private Manager $manager;
-	private ParticipantService $participantService;
 
 	public function __construct(
-		IConfig $config,
-		Manager $manager,
-		ParticipantService $participantService,
+		private IConfig $config,
+		private Manager $manager,
+		private ParticipantService $participantService,
 	) {
-		$this->config = $config;
-		$this->manager = $manager;
-		$this->participantService = $participantService;
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		if (!($event instanceof GroupDeletedEvent)) {
 			// Unrelated
@@ -66,7 +46,7 @@ class GroupDeletedListener implements IEventListener {
 		$rooms = $this->manager->getRoomsForActor(Attendee::ACTOR_GROUPS, $gid);
 		foreach ($rooms as $room) {
 			$participant = $this->participantService->getParticipantByActor($room, Attendee::ACTOR_GROUPS, $gid);
-			$this->participantService->removeAttendee($room, $participant, Room::PARTICIPANT_REMOVED);
+			$this->participantService->removeAttendee($room, $participant, AAttendeeRemovedEvent::REASON_REMOVED);
 		}
 	}
 
