@@ -14,6 +14,7 @@ use OCA\Talk\Events\RoomCreatedEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
 use OCA\Talk\Federation\Authenticator;
+use OCA\Talk\Model\Attachment;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\AttendeeMapper;
 use OCA\Talk\Model\SelectHelper;
@@ -122,6 +123,7 @@ class Manager {
 			'recording_consent' => 0,
 			'has_federation' => 0,
 			'mention_permissions' => 0,
+			'transcription_language' => '',
 		], $data));
 	}
 
@@ -191,6 +193,7 @@ class Manager {
 			(int)$row['recording_consent'],
 			(int)$row['has_federation'],
 			(int)$row['mention_permissions'],
+			(string)$row['transcription_language'],
 		);
 	}
 
@@ -477,13 +480,14 @@ class Manager {
 	 * @param string $userId
 	 * @return string[]
 	 */
-	public function getRoomTokensForUser(string $userId): array {
+	public function getRoomTokensWithAttachmentsForUser(string $userId): array {
 		$query = $this->db->getQueryBuilder();
 		$query->select('r.token')
 			->from('talk_attendees', 'a')
 			->leftJoin('a', 'talk_rooms', 'r', $query->expr()->eq('a.room_id', 'r.id'))
 			->where($query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)))
-			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)));
+			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
+			->andWhere($query->expr()->eq('r.has_attachments', $query->createNamedParameter(Attachment::ATTACHMENTS_ATLEAST_ONE)));
 
 		$result = $query->executeQuery();
 		$roomTokens = [];
@@ -599,6 +603,45 @@ class Manager {
 		return $room;
 	}
 
+	/**
+	 * Does *not* return public rooms for participants that have not been invited
+	 *
+	 * @param list<int> $roomIds
+	 * @param string $userId
+	 * @return array<int, Room> Key is the roomId
+	 */
+	public function getRoomsByIdForUser(array $roomIds, string $userId): array {
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$helper->selectAttendeesTable($query);
+		$query->from('talk_rooms', 'r')
+			->leftJoin('r', 'talk_attendees', 'a', $query->expr()->andX(
+				$query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)),
+				$query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)),
+				$query->expr()->eq('a.room_id', 'r.id')
+			))
+			->where($query->expr()->in('r.id', $query->createNamedParameter($roomIds, IQueryBuilder::PARAM_INT_ARRAY)))
+			->andWhere($query->expr()->isNotNull('a.id'));
+
+		$result = $query->executeQuery();
+		$rooms = [];
+		while ($row = $result->fetch()) {
+			if ($row['token'] === null) {
+				continue;
+			}
+
+			$room = $this->createRoomObject($row);
+			$participant = $this->createParticipantObject($room, $row);
+			$this->participantService->cacheParticipant($room, $participant);
+			$room->setParticipant($row['actor_id'], $participant);
+			$rooms[$room->getId()] = $room;
+		}
+		$result->closeCursor();
+
+		return $rooms;
+	}
+
 	/**
 	 * Returns room object for a user by token.
 	 *
