@@ -55,6 +55,7 @@ class Listener implements IEventListener {
 	) {
 	}
 
+	#[\Override]
 	public function handle(Event $event): void {
 		match (get_class($event)) {
 			CallNotificationSendEvent::class => $this->sendCallNotification($event->getRoom(), $event->getActor()?->getAttendee(), $event->getTarget()->getAttendee()),
@@ -222,7 +223,7 @@ class Listener implements IEventListener {
 		}
 
 		if ($this->shouldSendCallNotification || $event->getRoom()->isFederatedConversation()) {
-			$this->sendCallNotifications($event->getRoom());
+			$this->sendCallNotifications($event->getRoom(), $event->getDetailList(AParticipantModifiedEvent::DETAIL_IN_CALL_SILENT_FOR));
 		}
 	}
 
@@ -253,9 +254,9 @@ class Listener implements IEventListener {
 	/**
 	 * Call notification: "{user} wants to talk with you"
 	 *
-	 * @param Room $room
+	 * @param list<string> $silentFor
 	 */
-	protected function sendCallNotifications(Room $room): void {
+	protected function sendCallNotifications(Room $room, array $silentFor = []): void {
 		$actor = $this->userSession->getUser();
 		$actorId = $actor instanceof IUser ? $actor->getUID() :'';
 
@@ -284,11 +285,19 @@ class Listener implements IEventListener {
 		}
 
 		$this->preparedCallNotifications = [];
-		$userIds = $this->participantsService->getParticipantUserIdsForCallNotifications($room);
+		$users = $this->participantsService->getParticipantUsersForCallNotifications($room);
+
+		if (!empty($silentFor)) {
+			// Remove users for which the call should be silent
+			foreach ($silentFor as $userId) {
+				unset($users[$userId]);
+			}
+		}
+
 		// Room name depends on the notification user for one-to-one,
 		// so we avoid pre-parsing it there. Also, it comes with some base load,
 		// so we only do it for "big enough" calls.
-		$preparseNotificationForPush = count($userIds) > 10;
+		$preparseNotificationForPush = count($users) > 10;
 		if ($preparseNotificationForPush) {
 			$fallbackLang = $this->serverConfig->getSystemValue('force_language', null);
 			if (is_string($fallbackLang)) {
@@ -297,13 +306,14 @@ class Listener implements IEventListener {
 			} else {
 				$fallbackLang = $this->serverConfig->getSystemValueString('default_language', 'en');
 				/** @psalm-var array<string, string> $userLanguages */
-				$userLanguages = $this->serverConfig->getUserValueForUsers('core', 'lang', $userIds);
+				$userLanguages = $this->serverConfig->getUserValueForUsers('core', 'lang', array_map('strval', array_keys($users)));
 			}
 		}
 
 		$this->connection->beginTransaction();
 		try {
-			foreach ($userIds as $userId) {
+			foreach ($users as $userId => $isImportant) {
+				$userId = (string)$userId;
 				if ($actorId === $userId) {
 					continue;
 				}
@@ -326,6 +336,7 @@ class Listener implements IEventListener {
 
 				try {
 					$userNotification->setUser($userId);
+					$userNotification->setPriorityNotification($isImportant);
 					$this->notificationManager->notify($userNotification);
 				} catch (\InvalidArgumentException $e) {
 					$this->logger->error($e->getMessage(), ['exception' => $e]);
@@ -358,7 +369,8 @@ class Listener implements IEventListener {
 			$notification->setSubject('call', [
 				'callee' => $actor?->getActorId(),
 			])
-				->setDateTime($dateTime);
+				->setDateTime($dateTime)
+				->setPriorityNotification($target->isImportant());
 			$this->notificationManager->notify($notification);
 		} catch (\InvalidArgumentException $e) {
 			$this->logger->error($e->getMessage(), ['exception' => $e]);
