@@ -40,11 +40,22 @@ class Room {
 	public const TYPE_NOTE_TO_SELF = 6;
 
 	public const OBJECT_TYPE_EMAIL = 'emails';
-	public const OBJECT_TYPE_FILE = 'file';
-	public const OBJECT_TYPE_PHONE = 'phone';
-	public const OBJECT_TYPE_VIDEO_VERIFICATION = 'share:password';
-	public const OBJECT_TYPE_SAMPLE = 'sample';
 	public const OBJECT_TYPE_EVENT = 'event';
+	public const OBJECT_TYPE_EXTENDED_CONVERSATION = 'extended_conversation';
+	public const OBJECT_TYPE_FILE = 'file';
+	public const OBJECT_TYPE_INSTANT_MEETING = 'instant_meeting';
+	public const OBJECT_TYPE_NOTE_TO_SELF = 'note_to_self';
+	/**
+	 * @deprecated No longer used for new conversations
+	 */
+	public const OBJECT_TYPE_PHONE_LEGACY = 'phone';
+	public const OBJECT_TYPE_PHONE_PERSIST = 'phone_persist';
+	public const OBJECT_TYPE_PHONE_TEMPORARY = 'phone_temporary';
+	public const OBJECT_TYPE_SAMPLE = 'sample';
+	public const OBJECT_TYPE_VIDEO_VERIFICATION = 'share:password';
+
+	public const OBJECT_ID_PHONE_OUTGOING = 'phone';
+	public const OBJECT_ID_PHONE_INCOMING = 'direct-dialin';
 
 	public const RECORDING_NONE = 0;
 	public const RECORDING_VIDEO = 1;
@@ -89,9 +100,11 @@ class Room {
 	protected ?Participant $participant = null;
 
 	/**
-	 * @psalm-param Room::TYPE_* $type
+	 * @psalm-param self::TYPE_* $type
 	 * @psalm-param RecordingService::CONSENT_REQUIRED_* $recordingConsent
 	 * @psalm-param int-mask-of<self::HAS_FEDERATION_*> $hasFederation
+	 * @psalm-param self::RECORDING_* $callRecording
+	 * @psalm-param self::MENTION_PERMISSIONS_* $mentionPermissions
 	 */
 	public function __construct(
 		private Manager $manager,
@@ -129,6 +142,7 @@ class Room {
 		private int $recordingConsent,
 		private int $hasFederation,
 		private int $mentionPermissions,
+		private string $liveTranscriptionLanguageId,
 	) {
 	}
 
@@ -530,10 +544,16 @@ class Room {
 		$this->breakoutRoomStatus = $status;
 	}
 
+	/**
+	 * @psalm-return self::RECORDING_*
+	 */
 	public function getCallRecording(): int {
 		return $this->callRecording;
 	}
 
+	/**
+	 * @psalm-param self::RECORDING_* $callRecording
+	 */
 	public function setCallRecording(int $callRecording): void {
 		$this->callRecording = $callRecording;
 	}
@@ -568,11 +588,33 @@ class Room {
 		$this->hasFederation = $hasFederation;
 	}
 
+	/**
+	 * @psalm-return self::MENTION_PERMISSIONS_*
+	 */
 	public function getMentionPermissions(): int {
 		return $this->mentionPermissions;
 	}
 
+	/**
+	 * @psalm-param self::MENTION_PERMISSIONS_* $mentionPermissions
+	 */
 	public function setMentionPermissions(int $mentionPermissions): void {
 		$this->mentionPermissions = $mentionPermissions;
 	}
+
+	public function setObjectId(string $objectId): void {
+		$this->objectId = $objectId;
+	}
+
+	public function setObjectType(string $objectType): void {
+		$this->objectType = $objectType;
+	}
+
+	public function getLiveTranscriptionLanguageId(): string {
+		return $this->liveTranscriptionLanguageId;
+	}
+
+	public function setLiveTranscriptionLanguageId(string $liveTranscriptionLanguageId): void {
+		$this->liveTranscriptionLanguageId = $liveTranscriptionLanguageId;
+	}
 }
