@@ -9,8 +9,6 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Definition\Repository\ClassDefinitionRepository
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\ObjectType;
 use OCA\Talk\Vendor\Psr\SimpleCache\CacheInterface;
 
-use function sha1;
-
 /** @internal */
 final class CacheClassDefinitionRepository implements ClassDefinitionRepository
 {
@@ -23,7 +21,7 @@ final class CacheClassDefinitionRepository implements ClassDefinitionRepository
     public function for(ObjectType $type): ClassDefinition
     {
         // @infection-ignore-all
-        $key = 'class-definition' . sha1($type->toString());
+        $key = "class-definition-\0" . $type->toString();
 
         $entry = $this->cache->get($key);
 
