@@ -302,72 +302,122 @@ final class MapperBuilder
     }
 
     /**
-     * Changes the behaviours explained below:
+     * This setting will be removed in a future major version, as a replacement
+     * the following methods should be used:
      *
-     * ```php
-     * $flexibleMapper = (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
-     *     ->enableFlexibleCasting()
-     *     ->mapper();
-     *
-     * // ---
-     * // Scalar types will accept non-strict values; for instance an integer
-     * // type will accept any valid numeric value like the *string* "42".
-     *
-     * $flexibleMapper->map('int', '42');
-     * // => 42
-     *
-     * // ---
-     * // List type will accept non-incremental keys.
-     *
-     * $flexibleMapper->map('list<int>', ['foo' => 42, 'bar' => 1337]);
-     * // => [0 => 42, 1 => 1338]
-     *
-     * // ---
-     * // If a value is missing in a source for a node that accepts `null`, the
-     * // node will be filled with `null`.
-     *
-     * $flexibleMapper->map(
-     *     'array{foo: string, bar: null|string}',
-     *     ['foo' => 'foo'] // `bar` is missing
-     * );
-     * // => ['foo' => 'foo', 'bar' => null]
-     *
-     * // ---
-     * // Array and list types will convert `null` or missing values to an empty
-     * // array.
-     *
-     * $flexibleMapper->map(
-     *     'array{foo: string, bar: array<string>}',
-     *     ['foo' => 'foo'] // `bar` is missing
-     * );
-     * // => ['foo' => 'foo', 'bar' => []]
-     * ```
+     * - @see allowScalarValueCasting()
+     * - @see allowNonSequentialList()
+     * - @see allowUndefinedValues()
      */
     public function enableFlexibleCasting(): self
+    {
+        return $this
+            ->allowScalarValueCasting()
+            ->allowNonSequentialList()
+            ->allowUndefinedValues();
+    }
+
+    /**
+     * With this setting enabled, scalar types will accept castable values:
+     *
+     * - Integer types will accept any valid numeric value, for instance the
+     *   string value "42".
+     *
+     * - Float types will accept any valid numeric value, for instance the
+     *   string value "1337.42".
+     *
+     * - String types will accept any integer, float or object implementing the
+     *   `Stringable` interface.
+     *
+     * - Boolean types will accept any truthy or falsy value:
+     *     - "true" (string), "1" (string) and 1 (int) will be cast to `true`
+     *     - "false" (string), "0" (string) and 0 (int) will be cast to `false`
+     *
+     * ```php
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     ->allowScalarValueCasting()
+     *     ->mapper()
+     *     ->map('array{id: string, price: float, active: bool}', [
+     *         'id' => 549465210, // Will be cast to string
+     *         'price' => '42.39', // Will be cast to float
+     *         'active' => 1, // Will be cast to bool
+     *     ]);
+     * ```
+     */
+    public function allowScalarValueCasting(): self
     {
         $clone = clone $this;
-        $clone->settings->enableFlexibleCasting = true;
+        $clone->settings->allowScalarValueCasting = true;
 
         return $clone;
     }
 
     /**
-     * Superfluous keys in source arrays will be ignored, preventing errors when
-     * a value is not bound to any object property/parameter or shaped array
-     * element.
+     * By default, list types will only accept sequential keys starting from 0.
+     *
+     * This setting allows the mapper to convert associative arrays to a list
+     * with sequential keys.
+     *
+     * ```php
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     ->allowNonSequentialList()
+     *     ->mapper()
+     *     ->map('list<int>', [
+     *         'foo' => 42,
+     *         'bar' => 1337,
+     *     ]);
+     *
+     * // => [0 => 42, 1 => 1337]
+     * ```
+     */
+    public function allowNonSequentialList(): self
+    {
+        $clone = clone $this;
+        $clone->settings->allowNonSequentialList = true;
+
+        return $clone;
+    }
+
+    /**
+     * Allows the mapper to accept undefined values (missing from the input), by
+     * converting them to `null` (if the current type is nullable) or an empty
+     * array (if the current type is an object or an iterable).
+     *
+     * ```php
+     * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
+     *     ->allowUndefinedValues()
+     *     ->mapper()
+     *     ->map('array{name: string, age: int|null}', [
+     *         'name' => 'John Doe',
+     *         // 'age' is not defined
+     *     ]);
+     *
+     * // => ['name' => 'John Doe', 'age' => null]
+     * ```
+     */
+    public function allowUndefinedValues(): self
+    {
+        $clone = clone $this;
+        $clone->settings->allowUndefinedValues = true;
+
+        return $clone;
+    }
+
+    /**
+     * By default, an error is raised when a source array contains keys that
+     * do not match a class property/parameter or a shaped array element.
+     *
+     * This setting allows the mapper to ignore these superfluous keys.
      *
      * ```php
      * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
      *     ->allowSuperfluousKeys()
      *     ->mapper()
-     *     ->map(
-     *         'array{foo: string, bar: int}',
-     *         [
-     *             'foo' => 'foo',
-     *             'bar' => 42,
-     *             'baz' => 1337.404, // `baz` will be ignored
-     *         ]
-     *     );
+     *     ->map('array{name: string, age: int}', [
+     *         'name' => 'John Doe',
+     *         'age' => 42,
+     *         'city' => 'Paris', // Will be ignored
+     *     ]);
      * ```
      */
     public function allowSuperfluousKeys(): self
@@ -385,13 +435,10 @@ final class MapperBuilder
      * (new \OCA\Talk\Vendor\CuyZ\Valinor\MapperBuilder())
      *     ->allowPermissiveTypes()
      *     ->mapper()
-     *     ->map(
-     *         'array{foo: string, bar: mixed}',
-     *         [
-     *             'foo' => 'foo',
-     *             'bar' => 42, // Could be any value
-     *         ]
-     *     );
+     *     ->map('array{name: string, data: mixed}', [
+     *         'name' => 'some_product',
+     *         'data' => 42, // Could be any value
+     *     ]);
      * ```
      */
     public function allowPermissiveTypes(): self
