@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 use OCA\Talk\Vendor\CuyZ\Valinor\Utility\IsSingleton;
 
@@ -17,11 +19,21 @@ final class MixedType implements Type
         return true;
     }
 
+    public function compiledAccept(ComplianceNode $node): ComplianceNode
+    {
+        return Node::value(true);
+    }
+
     public function matches(Type $other): bool
     {
         return $other instanceof self;
     }
 
+    public function nativeType(): Type
+    {
+        return $this;
+    }
+
     public function toString(): string
     {
         return 'mixed';
