@@ -4,6 +4,8 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Vendor\CuyZ\Valinor\Type\Types;
 
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Native\ComplianceNode;
+use OCA\Talk\Vendor\CuyZ\Valinor\Compiler\Node;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\ErrorMessage;
 use OCA\Talk\Vendor\CuyZ\Valinor\Mapper\Tree\Message\MessageBuilder;
 use OCA\Talk\Vendor\CuyZ\Valinor\Type\StringType;
@@ -25,6 +27,11 @@ final class NativeStringType implements StringType
         return is_string($value);
     }
 
+    public function compiledAccept(ComplianceNode $node): ComplianceNode
+    {
+        return Node::functionCall('is_string', [$node]);
+    }
+
     public function matches(Type $other): bool
     {
         if ($other instanceof UnionType) {
@@ -32,6 +39,7 @@ final class NativeStringType implements StringType
         }
 
         return $other instanceof self
+            || $other instanceof ScalarConcreteType
             || $other instanceof MixedType;
     }
 
@@ -54,6 +62,11 @@ final class NativeStringType implements StringType
         return MessageBuilder::newError('Value {source_value} is not a valid string.')->build();
     }
 
+    public function nativeType(): NativeStringType
+    {
+        return $this;
+    }
+
     public function toString(): string
     {
         return 'string';
